@@ -8,6 +8,7 @@
 
 #include "3rd-party/expected.hpp"
 #include "configactionhandler.h"
+#include "filepath.h"
 
 namespace newsboat {
 
@@ -69,6 +70,7 @@ public:
 
 	bool get_configvalue_as_bool(const std::string& key) const;
 	int get_configvalue_as_int(const std::string& key) const;
+	Filepath get_configvalue_as_filepath(const std::string& key) const;
 	std::string get_configvalue(const std::string& key) const;
 	nonstd::expected<void, std::string> set_configvalue(const std::string& key,
 		const std::string& value);
