@@ -1,6 +1,8 @@
 #ifndef NEWSBOAT_CONTROLLER_H_
 #define NEWSBOAT_CONTROLLER_H_
 
+#include <memory>
+
 #include <libxml/tree.h>
 
 #include "cache.h"
@@ -25,8 +27,7 @@ class View;
 
 class Controller {
 public:
-	Controller(ConfigPaths& configpaths);
-	~Controller();
+	explicit Controller(ConfigPaths& configpaths);
 	void set_view(View* vv);
 	View* get_view()
 	{
@@ -62,15 +63,15 @@ public:
 		return &feedcontainer;
 	}
 
-	void write_item(RssItem& item, const std::string& filename);
+	void write_item(RssItem& item, const Filepath& filename);
 	void write_item(RssItem& item, std::ostream& ostr);
-	std::string write_temporary_item(RssItem& item);
+	Filepath write_temporary_item(RssItem& item);
 
 	void update_config();
 
-	void load_configfile(const std::string& filename);
+	void load_configfile(const Filepath& filename);
 
-	void dump_config(const std::string& filename) const;
+	void dump_config(const Filepath& filename) const;
 
 	void update_flags(std::shared_ptr<RssItem> item);
 
@@ -93,7 +94,7 @@ public:
 
 	RemoteApi* get_api()
 	{
-		return api;
+		return api.get();
 	}
 
 	RegexManager& get_regexmanager()
@@ -112,17 +113,17 @@ public:
 	}
 
 private:
-	int import_opml(const std::string& opmlFile, const std::string& urlFile);
+	int import_opml(const Filepath& opmlFile, const Filepath& urlFile);
 	void export_opml(bool version2);
 	void rec_find_rss_outlines(xmlNode* node, std::string tag);
 	int execute_commands(const std::vector<std::string>& cmds);
 
-	void import_read_information(const std::string& readinfofile);
-	void export_read_information(const std::string& readinfofile);
+	void import_read_information(const Filepath& readinfofile);
+	void export_read_information(const Filepath& readinfofile);
 
 	View* v;
-	UrlReader* urlcfg;
-	Cache* rsscache;
+	std::unique_ptr<UrlReader> urlcfg;
+	std::unique_ptr<Cache> rsscache;
 	bool refresh_on_start;
 	ConfigContainer cfg;
 	RssIgnores ign;
@@ -132,7 +133,7 @@ private:
 	ConfigParser cfgparser;
 	ColorManager colorman;
 	RegexManager rxman;
-	RemoteApi* api;
+	std::unique_ptr<RemoteApi> api;
 
 	FsLock fslock;
 
