@@ -1,7 +1,7 @@
 #ifndef NEWSBOAT_FEEDLISTFORMACTION_H_
 #define NEWSBOAT_FEEDLISTFORMACTION_H_
 
-#include "3rd-party/optional.hpp"
+#include <optional>
 
 #include "configcontainer.h"
 #include "history.h"
@@ -45,7 +45,7 @@ public:
 
 	void handle_cmdline(const std::string& cmd) override;
 
-	void finished_qna(Operation op) override;
+	void finished_qna(QnaFinishAction op) override;
 
 	void mark_pos_if_visible(unsigned int pos);
 
@@ -106,7 +106,7 @@ private:
 
 	FilterContainer& filter_container;
 
-	nonstd::optional<FeedSortStrategy> old_sort_strategy;
+	std::optional<FeedSortStrategy> old_sort_strategy;
 
 	Cache* cache;
 };
