@@ -38,7 +38,7 @@ struct Command {
 	CommandType type;
 	std::vector<std::string> args;
 
-	Command(CommandType type, std::vector<std::string> args = {})
+	explicit Command(CommandType type, std::vector<std::string> args = {})
 		: type(type)
 		, args(args)
 	{}
@@ -117,10 +117,10 @@ public:
 	virtual std::vector<std::string> get_suggestions(
 		const std::string& fragment);
 
-	static void load_histories(const std::string& searchfile,
-		const std::string& cmdlinefile);
-	static void save_histories(const std::string& searchfile,
-		const std::string& cmdlinefile,
+	static void load_histories(const Filepath& searchfile,
+		const Filepath& cmdlinefile);
+	static void save_histories(const Filepath& searchfile,
+		const Filepath& cmdlinefile,
 		unsigned int limit);
 
 	std::string bookmark(const std::string& url,
@@ -132,6 +132,7 @@ protected:
 	virtual bool process_operation(Operation op,
 		const std::vector<std::string>& args,
 		BindingType bindingType = BindingType::BindKey) = 0;
+	void report_unhandled_operation(Operation op);
 	void set_keymap_hints();
 
 	/// The name of the "main" STFL widget, i.e. the one that should be focused
