@@ -11,15 +11,15 @@ class RemoteApi;
 class FreshRssUrlReader : public UrlReader {
 public:
 	FreshRssUrlReader(ConfigContainer* c,
-		const std::string& url_file,
+		const Filepath& url_file,
 		RemoteApi* a);
 	~FreshRssUrlReader() override;
-	nonstd::optional<utils::ReadTextFileError> reload() override;
-	std::string get_source() override;
+	std::optional<utils::ReadTextFileError> reload() override;
+	std::string get_source() const override;
 
 private:
 	ConfigContainer* cfg;
-	std::string file;
+	Filepath file;
 	RemoteApi* api;
 };
 
