@@ -6,6 +6,7 @@
 #include "regexmanager.h"
 #include "textformatter.h"
 #include "textviewwidget.h"
+#include "filepath.h"
 
 namespace newsboat {
 
@@ -42,7 +43,7 @@ public:
 	}
 	std::string title() override;
 
-	void finished_qna(Operation op) override;
+	void finished_qna(QnaFinishAction op) override;
 
 	void render_html(
 		const std::string& source,
@@ -79,7 +80,7 @@ private:
 		std::string source);
 
 	void do_search();
-	void handle_save(const std::string& filename_param);
+	void handle_save(const Filepath& filename_param);
 
 	std::string guid;
 	std::shared_ptr<RssFeed> feed;
