@@ -11,9 +11,9 @@ namespace newsboat {
 
 class OpmlUrlReader : public UrlReader {
 public:
-	explicit OpmlUrlReader(ConfigContainer& c);
-	nonstd::optional<utils::ReadTextFileError> reload() override;
-	std::string get_source() override;
+	explicit OpmlUrlReader(ConfigContainer& c, const Filepath& url_file);
+	std::optional<utils::ReadTextFileError> reload() override;
+	std::string get_source() const override;
 
 protected:
 	virtual void handle_node(xmlNode* node, const std::string& tag);
@@ -21,6 +21,7 @@ protected:
 
 private:
 	void rec_find_rss_outlines(xmlNode* node, std::string tag);
+	Filepath file;
 };
 
 }
