@@ -4,15 +4,18 @@
 #include <cstdint>
 #include <string>
 #include <tuple>
+#include <utility>
 #include <vector>
 
+#include "filepath.h"
+
 namespace newsboat {
 
 namespace strprintf {
 namespace detail {
 template<typename T, typename... Args>
 std::string fmt_impl(const std::string& format, const T& argument,
-	Args... args);
+	Args&& ... args);
 }
 
 std::pair<std::string, std::string> split_format(
@@ -21,83 +24,92 @@ std::pair<std::string, std::string> split_format(
 std::string fmt(const std::string& format);
 
 template<typename... Args>
-std::string fmt(const std::string& format, const char* argument, Args... args)
+std::string fmt(const std::string& format, const char* argument, Args&& ... args)
 {
-	return detail::fmt_impl(format, argument, args...);
+	return detail::fmt_impl(format, argument, std::forward<Args>(args)...);
 }
 
 template<typename... Args>
-std::string fmt(const std::string& format, const int32_t argument, Args... args)
+std::string fmt(const std::string& format, const int32_t argument, Args&& ... args)
 {
-	return detail::fmt_impl(format, argument, args...);
+	return detail::fmt_impl(format, argument, std::forward<Args>(args)...);
 }
 
 template<typename... Args>
 std::string fmt(const std::string& format, const std::uint32_t argument,
-	Args... args)
+	Args&& ... args)
 {
-	return detail::fmt_impl(format, argument, args...);
+	return detail::fmt_impl(format, argument, std::forward<Args>(args)...);
 }
 
 template<typename... Args>
-std::string fmt(const std::string& format, const int64_t argument, Args... args)
+std::string fmt(const std::string& format, const int64_t argument, Args&& ... args)
 {
-	return detail::fmt_impl(format, argument, args...);
+	return detail::fmt_impl(format, argument, std::forward<Args>(args)...);
 }
 
 template<typename... Args>
 std::string fmt(const std::string& format, const uint64_t argument,
-	Args... args)
+	Args&& ... args)
 {
-	return detail::fmt_impl(format, argument, args...);
+	return detail::fmt_impl(format, argument, std::forward<Args>(args)...);
 }
 
 template<typename... Args>
-std::string fmt(const std::string& format, const void* argument, Args... args)
+std::string fmt(const std::string& format, const void* argument, Args&& ... args)
 {
-	return detail::fmt_impl(format, argument, args...);
+	return detail::fmt_impl(format, argument, std::forward<Args>(args)...);
 }
 
 template<typename... Args>
 std::string fmt(const std::string& format, const std::nullptr_t argument,
-	Args... args)
+	Args&& ... args)
 {
-	return detail::fmt_impl(format, argument, args...);
+	return detail::fmt_impl(format, argument, std::forward<Args>(args)...);
 }
 
 template<typename... Args>
-std::string fmt(const std::string& format, const float argument, Args... args)
+std::string fmt(const std::string& format, const float argument, Args&& ... args)
 {
 	// Variadic functions (like snprintf) do not accept `float`, so let's
 	// convert that.
-	return detail::fmt_impl(format, static_cast<double>(argument), args...);
+	return detail::fmt_impl(format, static_cast<double>(argument),
+			std::forward<Args>(args)...);
 }
 
 template<typename... Args>
-std::string fmt(const std::string& format, const double argument, Args... args)
+std::string fmt(const std::string& format, const double argument, Args&& ... args)
 {
-	return detail::fmt_impl(format, argument, args...);
+	return detail::fmt_impl(format, argument, std::forward<Args>(args)...);
 }
 
 template<typename... Args>
 std::string fmt(const std::string& format,
 	const std::string& argument,
-	Args... args)
+	Args&& ... args)
 {
-	return fmt(format, argument.c_str(), args...);
+	return fmt(format, argument.c_str(), std::forward<Args>(args)...);
 }
 
 template<typename... Args>
 std::string fmt(const std::string& format,
 	const std::string* argument,
-	Args... args)
+	Args&& ... args)
 {
-	return fmt(format, argument->c_str(), args...);
+	return fmt(format, argument->c_str(), std::forward<Args>(args)...);
+}
+
+template<typename... Args>
+std::string fmt(const std::string& format,
+	const Filepath& argument,
+	Args&& ... args)
+{
+	return fmt(format, argument.display(), std::forward<Args>(args)...);
 }
 
 namespace detail {
 template<typename T, typename... Args>
-std::string fmt_impl(const std::string& format, const T& argument, Args... args)
+std::string fmt_impl(const std::string& format, const T& argument, Args&& ... args)
 {
 	std::string local_format, remaining_format;
 	std::tie(local_format, remaining_format) = split_format(format);
@@ -120,12 +132,11 @@ std::string fmt_impl(const std::string& format, const T& argument, Args... args)
 		result = buffer;
 	} else {
 		std::vector<char> buf(len);
-		snprintf(
-			buf.data(), len, local_format.c_str(), argument);
+		snprintf(buf.data(), len, local_format.c_str(), argument);
 		result = buf.data();
 	}
 
-	return result + fmt(remaining_format, args...);
+	return result + fmt(remaining_format, std::forward<Args>(args)...);
 }
 }
 };
