@@ -16,7 +16,7 @@ public:
 	~UrlViewFormAction() override = default;
 	void prepare() override;
 	void init() override;
-	const std::vector<KeyMapHintEntry>& get_keymap_hint() const override;
+	std::vector<KeyMapHintEntry> get_keymap_hint() const override;
 	void set_links(const Links& l)
 	{
 		links = l;
@@ -42,7 +42,6 @@ private:
 	void update_heading();
 
 	Links links;
-	bool quit;
 	std::shared_ptr<RssFeed> feed;
 	ListWidget urls_list;
 };
