@@ -3,9 +3,10 @@
 
 #include <curl/curl.h>
 #include <libxml/parser.h>
+#include <optional>
 #include <string>
 
-#include "3rd-party/optional.hpp"
+#include "filepath.h"
 #include "remoteapi.h"
 #include "feed.h"
 
@@ -23,7 +24,7 @@ public:
 		const std::string& user_agent = "",
 		const std::string& proxy = "",
 		const std::string& proxy_auth = "",
-		curl_proxytype proxy_type = CURLPROXY_HTTP,
+		long int proxy_type = CURLPROXY_HTTP,
 		const bool ssl_verify = true);
 	~Parser();
 	Feed parse_url(const std::string& url,
@@ -33,8 +34,8 @@ public:
 		newsboat::RemoteApi* api = 0,
 		const std::string& cookie_cache = "");
 	Feed parse_buffer(const std::string& buffer,
-		const std::string& url = "", nonstd::optional<std::string> charset = nonstd::nullopt);
-	Feed parse_file(const std::string& filename);
+		const std::string& url = "", std::optional<std::string> charset = std::nullopt);
+	Feed parse_file(const newsboat::Filepath& filename);
 	time_t get_last_modified()
 	{
 		return lm;
@@ -53,7 +54,7 @@ private:
 	const std::string ua;
 	const std::string prx;
 	const std::string prxauth;
-	curl_proxytype prxtype;
+	long int prxtype;
 	const bool verify_ssl;
 	xmlDocPtr doc;
 	time_t lm;
