@@ -1,7 +1,7 @@
 use crate::abort_on_panic;
 use libnewsboat::human_panic;
 
-#[no_mangle]
+#[unsafe(no_mangle)]
 pub extern "C" fn rs_setup_human_panic() {
     abort_on_panic(|| {
         human_panic::setup();
