@@ -103,9 +103,9 @@ impl ConfigPaths {
     fn migrate_data_from_newsbeuter_xdg(&mut self) -> bool {
         // This can't panic because we've tested we can find the home directory in ConfigPaths::new
         // This should be replaced with proper error handling after this is not used by c++ anymore
-        let xdg_dirs = xdg::BaseDirectories::new().unwrap();
-        let xdg_config_dir = xdg_dirs.get_config_home();
-        let xdg_data_dir = xdg_dirs.get_data_home();
+        let xdg_dirs = xdg::BaseDirectories::new();
+        let xdg_config_dir = xdg_dirs.get_config_home().unwrap();
+        let xdg_data_dir = xdg_dirs.get_data_home().unwrap();
 
         let newsbeuter_config_dir = xdg_config_dir.join(NEWSBEUTER_SUBDIR_XDG);
         let newsbeuter_data_dir = xdg_data_dir.join(NEWSBEUTER_SUBDIR_XDG);
@@ -273,9 +273,12 @@ impl ConfigPaths {
     fn find_dirs_xdg(&mut self) {
         // This can't panic because we've tested we can find the home directory in ConfigPaths::new
         // This should be replaced with proper error handling after this is not used by c++ anymore
-        let xdg_dirs = xdg::BaseDirectories::new().unwrap();
-        let config_dir = xdg_dirs.get_config_home().join(NEWSBOAT_SUBDIR_XDG);
-        let data_dir = xdg_dirs.get_data_home().join(NEWSBOAT_SUBDIR_XDG);
+        let xdg_dirs = xdg::BaseDirectories::new();
+        let config_dir = xdg_dirs
+            .get_config_home()
+            .unwrap()
+            .join(NEWSBOAT_SUBDIR_XDG);
+        let data_dir = xdg_dirs.get_data_home().unwrap().join(NEWSBOAT_SUBDIR_XDG);
 
         if !config_dir.is_dir() {
             return;
