@@ -1,14 +1,14 @@
 //! Parses filter expressions.
 
 use gettextrs::gettext;
+use nom::AsChar;
 use nom::{
+    IResult, Offset, Parser,
     branch::alt,
     bytes::complete::{escaped, is_not, tag, take, take_while, take_while1},
-    character::{is_alphanumeric, is_digit},
     combinator::{complete, map, opt, peek, recognize, value},
     error::{ErrorKind, ParseError},
-    sequence::{delimited, separated_pair, terminated, tuple},
-    IResult, Offset, Parser,
+    sequence::{delimited, separated_pair, terminated},
 };
 use regex_rs::Regex;
 use std::cell::OnceCell;
@@ -198,7 +198,7 @@ fn expect<I: Clone, E: ExpectativeError<I>, F, O>(
     mut f: F,
 ) -> impl FnMut(I) -> IResult<I, O, E>
 where
-    F: Parser<I, O, E>,
+    F: Parser<I, Output = O, Error = E>,
 {
     move |i: I| match f.parse(i.clone()) {
         Ok(o) => Ok(o),
@@ -228,7 +228,8 @@ fn operators<'a, E: ParseError<&'a str> + ExpectativeError<&'a str>>(
             value(Operator::Contains, tag("#")),
             value(Operator::NotContains, tag("!#")),
         )),
-    )(input)
+    )
+    .parse(input)
 }
 
 fn quoted_string<'a, E: ParseError<&'a str>>(input: &'a str) -> IResult<&'a str, Value, E> {
@@ -238,19 +239,21 @@ fn quoted_string<'a, E: ParseError<&'a str>>(input: &'a str) -> IResult<&'a str,
             tag("\""),
             escaped(is_not("\\\""), '\\', take(1usize)),
             tag("\""),
-        )(input)?;
+        )
+        .parse(input)?;
         Ok((leftovers, String::from(chr)))
     };
 
-    map(alt((nonempty_string, empty_string)), Value::new)(input)
+    map(alt((nonempty_string, empty_string)), Value::new).parse(input)
 }
 
 fn number<'a, E: ParseError<&'a str>>(input: &'a str) -> IResult<&'a str, &'a str, E> {
-    recognize(tuple((opt(tag("-")), take_while1(|c| is_digit(c as u8)))))(input)
+    recognize((opt(tag("-")), take_while1(|c: char| c.is_dec_digit()))).parse(input)
 }
 
 fn range<'a, E: ParseError<&'a str>>(input: &'a str) -> IResult<&'a str, Value, E> {
-    separated_pair(number, tag(":"), number)(input)
+    separated_pair(number, tag(":"), number)
+        .parse(input)
         .map(|(leftovers, (a, b))| (leftovers, Value::new(format!("{a}:{b}"))))
 }
 
@@ -277,7 +280,9 @@ fn comparison<'a, E: ParseError<&'a str> + ExpectativeError<&'a str>>(
     // especific error message when this parser fails.
     let mut attribute_name = expect(
         Expected::AttributeName,
-        take_while1(|c| is_alphanumeric(c as u8) || c == '_' || c == '-' || c == '.'),
+        take_while1(|c: char| {
+            c.is_ascii() && (c.is_alphanum() || c == '_' || c == '-' || c == '.')
+        }),
     );
 
     let (input, attr) = attribute_name(input)?;
@@ -311,7 +316,7 @@ fn parens<'a, E: ParseError<&'a str> + ExpectativeError<&'a str>>(
 ) -> IResult<&'a str, Expression, E> {
     let (input, _) = tag("(")(input)?;
     let (input, _) = space0(input)?;
-    let (input, result) = alt((expression, parens, comparison))(input)?;
+    let (input, result) = alt((expression, parens, comparison)).parse(input)?;
     let (input, _) = space0(input)?;
     let (leftovers, _) = tag(")")(input)?;
 
@@ -331,9 +336,9 @@ fn parens<'a, E: ParseError<&'a str> + ExpectativeError<&'a str>>(
 /// While this one is invalid:
 /// - "x=1andy=0": no space between operator `and` and attribute name `y`
 fn space_after_logop<'a, E: ParseError<&'a str>>(input: &'a str) -> IResult<&'a str, &'a str, E> {
-    let opt_space_and_paren = recognize(tuple((space0, tag("("))));
+    let opt_space_and_paren = recognize((space0, tag("(")));
     let parser = alt((opt_space_and_paren, space1));
-    peek(parser)(input)
+    peek(parser).parse(input)
 }
 
 fn expression<'a, E: ParseError<&'a str> + ExpectativeError<&'a str>>(
@@ -350,14 +355,15 @@ fn expression<'a, E: ParseError<&'a str> + ExpectativeError<&'a str>>(
         Or,
     }
 
-    let (input, left) = alt((parens, comparison))(input)?;
+    let (input, left) = alt((parens, comparison)).parse(input)?;
     let (input, _) = space0(input)?;
     let (input, op) = terminated(
         alt((value(Op::And, tag("and")), value(Op::Or, tag("or")))),
         space_after_logop,
-    )(input)?;
+    )
+    .parse(input)?;
     let (input, _) = space0(input)?;
-    let (leftovers, right) = alt((expression, parens, comparison))(input)?;
+    let (leftovers, right) = alt((expression, parens, comparison)).parse(input)?;
 
     let op = match op {
         Op::And => Expression::And(Box::new(left), Box::new(right)),
@@ -375,10 +381,10 @@ fn parser<'a, E: ParseError<&'a str> + ExpectativeError<&'a str>>(
     let parsers = delimited(space0, parsers, space0);
     // Try to parse input. If parser says it needs more data, make that an error, since `input` is
     // all we got.
-    complete(parsers)(input)
+    complete(parsers).parse(input)
 }
 
-fn internal_parse(expr: &str) -> Result<Expression, Error> {
+fn internal_parse(expr: &str) -> Result<Expression, Error<'_>> {
     match parser::<FilterParserError>(expr) {
         Ok((leftovers, expression)) => {
             if leftovers.is_empty() {
@@ -393,7 +399,7 @@ fn internal_parse(expr: &str) -> Result<Expression, Error> {
                     let pos = expr.offset(chunk);
                     match err {
                         FilterParserErrorKind::Unexpected(expected) => {
-                            return Error::AtPos(pos, expected)
+                            return Error::AtPos(pos, expected);
                         }
                         _ => continue,
                     }
