@@ -1,12 +1,13 @@
 //! Keeps a record of what the program did.
 
-use chrono::{offset::Local, Datelike, Timelike};
+use chrono::{Datelike, Timelike, offset::Local};
 use std::fmt;
 use std::fs::{File, OpenOptions};
 use std::io::Write;
-use std::sync::atomic::{AtomicIsize, Ordering};
+use std::path::Path;
 use std::sync::Mutex;
 use std::sync::OnceLock;
+use std::sync::atomic::{AtomicIsize, Ordering};
 
 #[derive(Clone, Copy, PartialEq, Eq, PartialOrd, Ord, Debug)]
 /// "Importance levels" for log messages.
@@ -139,15 +140,15 @@ impl Logger {
     ///
     /// This can't fail, but if the file couldn't be created or opened, an error message will be
     /// printed to stderr.
-    pub fn set_logfile(&self, filename: &str) {
-        let file = OpenOptions::new().create(true).append(true).open(filename);
+    pub fn set_logfile<P: AsRef<Path> + fmt::Debug>(&self, filename: P) {
+        let file = OpenOptions::new().create(true).append(true).open(&filename);
 
         match file {
             Ok(file) => {
                 let mut files = self.files.lock().expect("Someone poisoned logger's mutex");
                 files.logfile = Some(file);
             }
-            Err(error) => eprintln!("Couldn't open `{filename}' as a logfile: {error}"),
+            Err(error) => eprintln!("Couldn't open `{filename:?}' as a logfile: {error}"),
         }
     }
 
@@ -162,15 +163,17 @@ impl Logger {
     ///
     /// This can't fail, but if the file couldn't be created or opened, an error message will be
     /// printed to stderr.
-    pub fn set_user_error_logfile(&self, filename: &str) {
-        let file = OpenOptions::new().create(true).append(true).open(filename);
+    pub fn set_user_error_logfile<P: AsRef<Path> + fmt::Debug>(&self, filename: P) {
+        let file = OpenOptions::new().create(true).append(true).open(&filename);
 
         match file {
             Ok(file) => {
                 let mut files = self.files.lock().expect("Someone poisoned logger's mutex");
                 files.user_error_logfile = Some(file)
             }
-            Err(error) => eprintln!("Couldn't open `{filename}' as a user error logfile: {error}"),
+            Err(error) => {
+                eprintln!("Couldn't open `{filename:?}' as a user error logfile: {error}")
+            }
         }
     }
 
@@ -217,6 +220,7 @@ impl Logger {
 
         let mut files = self.files.lock().expect("Someone poisoned logger's mutex");
 
+        #[allow(clippy::collapsible_if)] // Necessary until MSRV is Rust 1.88.0 or higher
         if level as isize <= self.get_loglevel() {
             if let Some(ref mut logfile) = files.logfile {
                 let level = format!("{level}: ");
@@ -229,6 +233,7 @@ impl Logger {
             }
         }
 
+        #[allow(clippy::collapsible_if)] // Necessary until MSRV is Rust 1.88.0 or higher
         if level == Level::UserError {
             if let Some(ref mut user_error_logfile) = files.user_error_logfile {
                 // Ignoring the error since checking every log() call will be too bothersome.
@@ -504,7 +509,7 @@ mod tests {
 
                     assert_eq!(message, expected);
                 }
-                Err(e) => panic!("Error reading a line from the log: {:?}", e),
+                Err(e) => panic!("Error reading a line from the log: {e:?}"),
             }
         }
     }
@@ -545,7 +550,7 @@ mod tests {
 
                     assert_eq!(level, expected);
                 }
-                Err(e) => panic!("Error reading a line from the log: {:?}", e),
+                Err(e) => panic!("Error reading a line from the log: {e:?}"),
             }
         }
     }
@@ -835,7 +840,7 @@ mod tests {
 
                     assert_eq!(message, expected);
                 }
-                Err(e) => panic!("Error reading a line from the log: {:?}", e),
+                Err(e) => panic!("Error reading a line from the log: {e:?}"),
             }
         }
     }
