@@ -6,7 +6,7 @@ use tempfile::TempDir;
 fn t_cliargsparser_dash_capital_e_resolves_tilde_to_homedir() {
     let tmp = TempDir::new().unwrap();
 
-    env::set_var("HOME", tmp.path());
+    unsafe { env::set_var("HOME", tmp.path()) };
 
     let filename = "read.txt";
     let arg = format!("~/{filename}");
