@@ -9,12 +9,12 @@ fn t_returns_paths_to_newsboat_dotdir_if_no_newsboat_dirs_exist() {
     let newsboat_dir = tmp.path().join(".newsboat");
     fs::create_dir_all(&newsboat_dir).ok();
 
-    env::set_var("HOME", tmp.path());
+    unsafe { env::set_var("HOME", tmp.path()) };
 
     // ConfigPaths rely on these variables, so let's sanitize them to ensure
     // that the tests aren't affected
-    env::remove_var("XDG_CONFIG_HOME");
-    env::remove_var("XDG_DATA_HOME");
+    unsafe { env::remove_var("XDG_CONFIG_HOME") };
+    unsafe { env::remove_var("XDG_DATA_HOME") };
 
     let paths = ConfigPaths::new();
     assert!(paths.initialized());
