@@ -178,7 +178,7 @@ impl<'a> Chmod<'a> {
     }
 }
 
-impl<'a> Drop for Chmod<'a> {
+impl Drop for Chmod<'_> {
     fn drop(&mut self) {
         fs::set_permissions(self.path, fs::Permissions::from_mode(self.original_mode))
             .unwrap_or_else(|_| {
