@@ -1,4 +1,4 @@
-use libc::{setlocale, LC_CTYPE};
+use libc::{LC_CTYPE, setlocale};
 use std::env;
 use std::ffi::CString;
 
@@ -8,7 +8,7 @@ pub fn set_locale(new_locale: &str) {
         let locale_set = setlocale(LC_CTYPE, c_new_locale.as_ptr());
 
         if locale_set.is_null() {
-            panic!("Couldn't set locale {}; test skipped.", new_locale);
+            panic!("Couldn't set locale {new_locale}; test skipped.");
         }
 
         env::set_var("LC_CTYPE", new_locale);
