@@ -17,7 +17,7 @@
 
 namespace newsboat {
 
-const std::string ConfigContainer::PARTIAL_FILE_SUFFIX = ".part";
+const std::string ConfigContainer::PARTIAL_FILE_SUFFIX = "part";
 
 ConfigContainer::ConfigContainer()
 // create the config options and set their resp. default value and type
@@ -40,10 +40,19 @@ ConfigContainer::ConfigContainer()
 		ConfigData("false", ConfigDataType::BOOL)},
 	{
 		"browser",
-		ConfigData(utils::get_default_browser(),
+		ConfigData(utils::get_default_browser().to_locale_string(),
 			ConfigDataType::PATH)},
 	{"cache-file", ConfigData("", ConfigDataType::PATH)},
-	{"cleanup-on-quit", ConfigData("yes", ConfigDataType::BOOL)},
+	{
+		"cleanup-on-quit",
+		ConfigData("nudge",
+		std::unordered_set<std::string>({
+			"yes",
+			"no",
+			"nudge",
+			// true/false only added for backwards compatiblity as this option was previously a bool
+			"true",
+			"false"}))},
 	{"confirm-delete-all-articles", ConfigData("yes", ConfigDataType::BOOL)},
 	{"confirm-mark-all-feeds-read", ConfigData("yes", ConfigDataType::BOOL)},
 	{"confirm-mark-feed-read", ConfigData("yes", ConfigDataType::BOOL)},
@@ -364,17 +373,17 @@ void ConfigContainer::handle_action(const std::string& action,
 	const std::vector<std::string>& params)
 {
 	std::lock_guard<std::recursive_mutex> guard(config_data_mtx);
-	ConfigData& cfgdata = config_data[action];
+	auto entry = config_data.find(action);
 
-	// ConfigDataType::INVALID indicates that the action didn't exist, and
-	// that the returned object was created ad-hoc.
-	if (cfgdata.type() == ConfigDataType::INVALID) {
+	if (entry == config_data.end()) {
 		LOG(Level::WARN,
 			"ConfigContainer::handle_action: unknown action %s",
 			action);
 		throw ConfigHandlerException(ActionHandlerStatus::INVALID_COMMAND);
 	}
 
+	auto& cfgdata = entry->second;
+
 	LOG(Level::DEBUG,
 		"ConfigContainer::handle_action: action = %s, type = %u",
 		action,
@@ -405,10 +414,6 @@ void ConfigContainer::handle_action(const std::string& action,
 			cfgdata.set_value(params[0]);
 		}
 		break;
-
-	case ConfigDataType::INVALID:
-		// we already handled this at the beginning of the function
-		break;
 	}
 }
 
@@ -418,11 +423,7 @@ std::string ConfigContainer::get_configvalue(const std::string& key) const
 	auto it = config_data.find(key);
 	if (it != config_data.cend()) {
 		const auto& entry = it->second;
-		std::string value = entry.value();
-		if (entry.type() == ConfigDataType::PATH) {
-			value = utils::resolve_tilde(value);
-		}
-		return value;
+		return entry.value();
 	}
 
 	return {};
@@ -443,6 +444,20 @@ int ConfigContainer::get_configvalue_as_int(const std::string& key) const
 	return 0;
 }
 
+Filepath ConfigContainer::get_configvalue_as_filepath(const std::string& key) const
+{
+	std::lock_guard<std::recursive_mutex> guard(config_data_mtx);
+	auto it = config_data.find(key);
+	if (it != config_data.cend()) {
+		const auto& entry = it->second;
+		if (entry.type() == ConfigDataType::PATH) {
+			return utils::resolve_tilde(Filepath::from_locale_string(entry.value()));
+		}
+	}
+
+	return {};
+}
+
 bool ConfigContainer::get_configvalue_as_bool(const std::string& key) const
 {
 	std::lock_guard<std::recursive_mutex> guard(config_data_mtx);
@@ -455,7 +470,8 @@ bool ConfigContainer::get_configvalue_as_bool(const std::string& key) const
 	return false;
 }
 
-void ConfigContainer::set_configvalue(const std::string& key,
+nonstd::expected<void, std::string> ConfigContainer::set_configvalue(
+	const std::string& key,
 	const std::string& value)
 {
 	LOG(Level::DEBUG,
@@ -463,19 +479,30 @@ void ConfigContainer::set_configvalue(const std::string& key,
 		key,
 		value);
 	std::lock_guard<std::recursive_mutex> guard(config_data_mtx);
-	config_data[key].set_value(value);
+	auto config_option = config_data.find(key);
+	if (config_option != config_data.end()) {
+		return config_option->second.set_value(value);
+	} else {
+		return nonstd::make_unexpected(strprintf::fmt(
+					_("unknown config option: %s"),
+					key));
+	}
 }
 
 void ConfigContainer::reset_to_default(const std::string& key)
 {
 	std::lock_guard<std::recursive_mutex> guard(config_data_mtx);
-	config_data[key].reset_to_default();
+	auto entry = config_data.find(key);
+	if (entry != config_data.end()) {
+		entry->second.reset_to_default();
+	}
 }
 
 void ConfigContainer::toggle(const std::string& key)
 {
 	std::lock_guard<std::recursive_mutex> guard(config_data_mtx);
-	if (config_data[key].type() == ConfigDataType::BOOL) {
+	auto entry = config_data.find(key);
+	if (entry != config_data.end() && entry->second.type() == ConfigDataType::BOOL) {
 		set_configvalue(key,
 			std::string(get_configvalue_as_bool(key) ? "false"
 				: "true"));
@@ -487,7 +514,6 @@ void ConfigContainer::dump_config(std::vector<std::string>& config_output) const
 	std::lock_guard<std::recursive_mutex> guard(config_data_mtx);
 	for (const auto& cfg : config_data) {
 		std::string configline = cfg.first + " ";
-		assert(cfg.second.type() != ConfigDataType::INVALID);
 		switch (cfg.second.type()) {
 		case ConfigDataType::BOOL:
 		case ConfigDataType::INT:
@@ -517,10 +543,6 @@ void ConfigContainer::dump_config(std::vector<std::string>& config_output) const
 				}
 			}
 			break;
-		case ConfigDataType::INVALID:
-			// can't happen because we already checked this case
-			// before the `switch`
-			break;
 		}
 		config_output.push_back(configline);
 	}
@@ -564,6 +586,8 @@ FeedSortStrategy ConfigContainer::get_feed_sort_strategy() const
 		ss.sm = FeedSortMethod::UNREAD_ARTICLE_COUNT;
 	} else if (sortmethod == "lastupdated") {
 		ss.sm = FeedSortMethod::LAST_UPDATED;
+	} else if (sortmethod == "latestunread") {
+		ss.sm = FeedSortMethod::LATEST_UNREAD;
 	}
 
 	std::string direction = "desc";
