@@ -35,7 +35,6 @@
 #include "feedhqurlreader.h"
 #include "formaction.h"
 #include "feedbinapi.h"
-#include "feedbinurlreader.h"
 #include "freshrssapi.h"
 #include "freshrssurlreader.h"
 #include "fileurlreader.h"
@@ -46,22 +45,20 @@
 #include "minifluxapi.h"
 #include "minifluxurlreader.h"
 #include "newsblurapi.h"
-#include "newsblururlreader.h"
 #include "ocnewsapi.h"
-#include "ocnewsurlreader.h"
 #include "oldreaderapi.h"
 #include "oldreaderurlreader.h"
 #include "opml.h"
 #include "opmlurlreader.h"
 #include "regexmanager.h"
 #include "remoteapi.h"
+#include "remoteapiurlreader.h"
 #include "rssfeed.h"
 #include "rssparser.h"
 #include "scopemeasure.h"
 #include "stflpp.h"
 #include "strprintf.h"
 #include "ttrssapi.h"
-#include "ttrssurlreader.h"
 #include "utils.h"
 #include "view.h"
 
@@ -81,22 +78,12 @@ void ignore_signal(int sig)
 
 Controller::Controller(ConfigPaths& configpaths)
 	: v(0)
-	, urlcfg(0)
-	, rsscache(0)
 	, refresh_on_start(false)
-	, api(0)
 	, configpaths(configpaths)
 	, queueManager(&cfg, configpaths.queue_file())
 {
 }
 
-Controller::~Controller()
-{
-	delete rsscache;
-	delete urlcfg;
-	delete api;
-}
-
 void Controller::set_view(View* vv)
 {
 	v = vv;
@@ -116,13 +103,12 @@ int Controller::run(const CliArgsParser& args)
 
 	if (args.log_file().has_value()) {
 		logger::set_logfile(args.log_file().value());
-	}
-
-	if (!args.log_file().has_value() && args.log_level().has_value()) {
+	} else if (args.log_level().has_value()) {
 		const std::string date_time_string = utils::mt_strf_localtime("%Y-%m-%d_%H.%M.%S",
 				std::time(nullptr));
 		const std::string filename = "newsboat_" + date_time_string + ".log";
-		logger::set_logfile(filename);
+		const auto filepath = Filepath::from_locale_string(filename);
+		logger::set_logfile(filepath);
 	}
 
 	if (!args.display_msg().empty()) {
@@ -168,6 +154,7 @@ int Controller::run(const CliArgsParser& args)
 	colorman.register_commands(cfgparser);
 
 	KeyMap keys(KM_NEWSBOAT);
+	cfgparser.register_handler("bind", keys);
 	cfgparser.register_handler("bind-key", keys);
 	cfgparser.register_handler("unbind-key", keys);
 	cfgparser.register_handler("macro", keys);
@@ -183,14 +170,14 @@ int Controller::run(const CliArgsParser& args)
 	cfgparser.register_handler("highlight-feed", rxman);
 
 	try {
-		cfgparser.parse_file("/etc/" PACKAGE "/config");
+		cfgparser.parse_file(Filepath::from_locale_string("/etc/" PACKAGE "/config"));
 		cfgparser.parse_file(configpaths.config_file());
 	} catch (const ConfigException& ex) {
 		LOG(Level::ERROR,
 			"an exception occurred while parsing the configuration "
 			"file: %s",
 			ex.what());
-		std::cout << ex.what() << std::endl;
+		std::cerr << ex.what() << std::endl;
 		return EXIT_FAILURE;
 	}
 
@@ -201,8 +188,8 @@ int Controller::run(const CliArgsParser& args)
 	}
 
 	// create cache object
-	std::string cachefilepath = cfg.get_configvalue("cache-file");
-	if (cachefilepath.length() > 0 && !args.cache_file().has_value()) {
+	const auto cachefilepath = cfg.get_configvalue_as_filepath("cache-file");
+	if (cachefilepath != Filepath() && !args.cache_file().has_value()) {
 		configpaths.set_cache_file(cachefilepath);
 	}
 
@@ -210,14 +197,14 @@ int Controller::run(const CliArgsParser& args)
 	std::string error;
 	if (!fslock.try_lock(configpaths.lock_file(), pid, error)) {
 		if (pid != 0) {
-			std::cout << strprintf::fmt(
+			std::cerr << strprintf::fmt(
 					_("Error: an instance of %s is "
 						"already running (PID: %s)"),
 					PROGRAM_NAME,
 					std::to_string(pid))
 				<< std::endl;
 		} else {
-			std::cout << _("Error: ") << error << std::endl;
+			std::cerr << _("Error: ") << error << std::endl;
 		}
 		return EXIT_FAILURE;
 	}
@@ -227,7 +214,7 @@ int Controller::run(const CliArgsParser& args)
 		std::cout.flush();
 	}
 	try {
-		rsscache = new Cache(configpaths.cache_file(), &cfg);
+		rsscache = std::make_unique<Cache>(configpaths.cache_file(), cfg);
 	} catch (const DbException& e) {
 		std::cerr << strprintf::fmt(
 				_("Error: opening the cache file `%s' "
@@ -250,49 +237,50 @@ int Controller::run(const CliArgsParser& args)
 		std::cout << _("done.") << std::endl;
 	}
 
-	reloader = std::make_unique<Reloader>(this, rsscache, cfg);
+	reloader = std::make_unique<Reloader>(*this, *rsscache, cfg);
 
 	std::string type = cfg.get_configvalue("urls-source");
 	if (type == "local") {
-		urlcfg = new FileUrlReader(configpaths.url_file());
+		urlcfg = std::make_unique<FileUrlReader>(configpaths.url_file());
 	} else if (type == "opml") {
-		urlcfg = new OpmlUrlReader(cfg);
+		urlcfg = std::make_unique<OpmlUrlReader>(cfg, configpaths.url_file());
 	} else if (type == "oldreader") {
-		api = new OldReaderApi(cfg);
-		urlcfg = new OldReaderUrlReader(
-			&cfg, configpaths.url_file(), api);
+		api = std::make_unique<OldReaderApi>(cfg);
+		urlcfg = std::make_unique<OldReaderUrlReader>(
+				&cfg, configpaths.url_file(), api.get());
 	} else if (type == "ttrss") {
-		api = new TtRssApi(cfg);
-		urlcfg = new TtRssUrlReader(configpaths.url_file(), api);
+		api = std::make_unique<TtRssApi>(cfg);
+		urlcfg = std::make_unique<RemoteApiUrlReader>("Tiny Tiny RSS", configpaths.url_file(),
+				*api);
 	} else if (type == "newsblur") {
-		const auto cookies = cfg.get_configvalue("cookie-cache");
-		if (cookies.empty()) {
-			std::cout << strprintf::fmt(
+		const auto cookies = cfg.get_configvalue_as_filepath("cookie-cache");
+		if (cookies == Filepath()) {
+			std::cerr << strprintf::fmt(
 					_("ERROR: You must set `cookie-cache` to use "
 						"NewsBlur.\n"));
 			return EXIT_FAILURE;
 		}
 
-		std::ofstream check(cookies);
+		std::ofstream check(cookies.to_locale_string());
 		if (!check.is_open()) {
-			std::cout << strprintf::fmt(
+			std::cerr << strprintf::fmt(
 					_("%s is inaccessible and can't be created\n"),
 					cookies);
 			return EXIT_FAILURE;
 		}
 
-		api = new NewsBlurApi(cfg);
-		urlcfg = new NewsBlurUrlReader(configpaths.url_file(), api);
+		api = std::make_unique<NewsBlurApi>(cfg);
+		urlcfg = std::make_unique<RemoteApiUrlReader>("NewsBlur", configpaths.url_file(), *api);
 	} else if (type == "feedhq") {
-		api = new FeedHqApi(cfg);
-		urlcfg = new FeedHqUrlReader(&cfg, configpaths.url_file(), api);
+		api = std::make_unique<FeedHqApi>(cfg);
+		urlcfg = std::make_unique<FeedHqUrlReader>(&cfg, configpaths.url_file(), api.get());
 	} else if (type == "feedbin") {
 		const std::string user = cfg.get_configvalue("feedbin-login");
 		const std::string pass = cfg.get_configvalue("feedbin-password");
-		const std::string pass_file = cfg.get_configvalue("feedbin-passwordfile");
+		const auto pass_file = cfg.get_configvalue_as_filepath("feedbin-passwordfile");
 		const std::string pass_eval = cfg.get_configvalue("feedbin-passwordeval");
 		const bool creds_set = !user.empty() &&
-			(!pass.empty() || !pass_file.empty() || !pass_eval.empty());
+			(!pass.empty() || pass_file != Filepath() || !pass_eval.empty());
 		if (!creds_set) {
 			std::cerr <<
 				_("ERROR: You must set `feedbin-login` and one of `feedbin-password`, "
@@ -301,8 +289,8 @@ int Controller::run(const CliArgsParser& args)
 			return EXIT_FAILURE;
 		}
 
-		api = new FeedbinApi(cfg);
-		urlcfg = new FeedbinUrlReader(configpaths.url_file(), api);
+		api = std::make_unique<FeedbinApi>(cfg);
+		urlcfg = std::make_unique<RemoteApiUrlReader>("Feedbin", configpaths.url_file(), *api);
 	} else if (type == "freshrss") {
 		const auto freshrss_url = cfg.get_configvalue("freshrss-url");
 		if (freshrss_url.empty()) {
@@ -313,10 +301,10 @@ int Controller::run(const CliArgsParser& args)
 
 		const std::string user = cfg.get_configvalue("freshrss-login");
 		const std::string pass = cfg.get_configvalue("freshrss-password");
-		const std::string pass_file = cfg.get_configvalue("freshrss-passwordfile");
+		const auto pass_file = cfg.get_configvalue_as_filepath("freshrss-passwordfile");
 		const std::string pass_eval = cfg.get_configvalue("freshrss-passwordeval");
 		const bool creds_set = !user.empty() &&
-			(!pass.empty() || !pass_file.empty() || !pass_eval.empty());
+			(!pass.empty() || pass_file != Filepath() || !pass_eval.empty());
 		if (!creds_set) {
 			std::cerr <<
 				_("ERROR: You must set `freshrss-login` and one of `freshrss-password`, "
@@ -325,11 +313,12 @@ int Controller::run(const CliArgsParser& args)
 			return EXIT_FAILURE;
 		}
 
-		api = new FreshRssApi(cfg);
-		urlcfg = new FreshRssUrlReader(&cfg, configpaths.url_file(), api);
+		api = std::make_unique<FreshRssApi>(cfg);
+		urlcfg = std::make_unique<FreshRssUrlReader>(&cfg, configpaths.url_file(), api.get());
 	} else if (type == "ocnews") {
-		api = new OcNewsApi(cfg);
-		urlcfg = new OcNewsUrlReader(configpaths.url_file(), api);
+		api = std::make_unique<OcNewsApi>(cfg);
+		urlcfg = std::make_unique<RemoteApiUrlReader>("ownCloud News", configpaths.url_file(),
+				*api);
 	} else if (type == "miniflux") {
 		const auto miniflux_url = cfg.get_configvalue("miniflux-url");
 		if (miniflux_url.empty()) {
@@ -340,23 +329,23 @@ int Controller::run(const CliArgsParser& args)
 
 		const std::string user = cfg.get_configvalue("miniflux-login");
 		const std::string pass = cfg.get_configvalue("miniflux-password");
-		const std::string pass_file = cfg.get_configvalue("miniflux-passwordfile");
+		const auto pass_file = cfg.get_configvalue_as_filepath("miniflux-passwordfile");
 		const std::string pass_eval = cfg.get_configvalue("miniflux-passwordeval");
 		const std::string token = cfg.get_configvalue("miniflux-token");
-		const std::string token_file = cfg.get_configvalue("miniflux-tokenfile");
+		const auto token_file = cfg.get_configvalue_as_filepath("miniflux-tokenfile");
 		const std::string token_eval = cfg.get_configvalue("miniflux-tokeneval");
 		const bool creds_set = !token.empty()
-			|| !token_file.empty()
+			|| token_file != Filepath()
 			|| !token_eval.empty()
-			|| (!user.empty() && (!pass.empty() || !pass_file.empty() || !pass_eval.empty()));
+			|| (!user.empty() && (!pass.empty() || pass_file != Filepath() || !pass_eval.empty()));
 		if (!creds_set) {
 			std::cerr <<
 				_("ERROR: You must provide an API token or a login/password pair to use Miniflux. Please set the appropriate miniflux-* settings\n");
 			return EXIT_FAILURE;
 		}
 
-		api = new MinifluxApi(cfg);
-		urlcfg = new MinifluxUrlReader(&cfg, configpaths.url_file(), api);
+		api = std::make_unique<MinifluxApi>(cfg);
+		urlcfg = std::make_unique<MinifluxUrlReader>(&cfg, configpaths.url_file(), api.get());
 	} else if (type == "inoreader") {
 		const auto all_set = !cfg.get_configvalue("inoreader-app-id").empty()
 			&& !cfg.get_configvalue("inoreader-app-key").empty();
@@ -366,8 +355,8 @@ int Controller::run(const CliArgsParser& args)
 			return EXIT_FAILURE;
 		}
 
-		api = new InoreaderApi(cfg);
-		urlcfg = new InoreaderUrlReader(&cfg, configpaths.url_file(), api);
+		api = std::make_unique<InoreaderApi>(cfg);
+		urlcfg = std::make_unique<InoreaderUrlReader>(&cfg, configpaths.url_file(), api.get());
 	} else {
 		std::cerr << strprintf::fmt(_("ERROR: Unknown urls-source `%s'"),
 				type) << std::endl;
@@ -387,7 +376,7 @@ int Controller::run(const CliArgsParser& args)
 	}
 	const auto error_message = urlcfg->reload();
 	if (error_message.has_value()) {
-		std::cout << error_message.value().message << std::endl << std::endl;
+		std::cerr << error_message.value().message << std::endl << std::endl;
 	} else if (!args.do_export() && !args.silent()) {
 		std::cout << _("done.") << std::endl;
 	}
@@ -444,7 +433,7 @@ int Controller::run(const CliArgsParser& args)
 		} else {
 			assert(0); // shouldn't happen
 		}
-		std::cout << msg << std::endl << std::endl;
+		std::cerr << msg << std::endl << std::endl;
 		return EXIT_FAILURE;
 	}
 
@@ -476,12 +465,12 @@ int Controller::run(const CliArgsParser& args)
 			feed->set_order(i);
 			feedcontainer.add_feed(feed);
 		} catch (const DbException& e) {
-			std::cout << _("Error while loading feeds from "
+			std::cerr << _("Error while loading feeds from "
 					"database: ")
 				<< e.what() << std::endl;
 			return EXIT_FAILURE;
 		} catch (const std::string& str) {
-			std::cout << strprintf::fmt(
+			std::cerr << strprintf::fmt(
 					_("Error while loading feed '%s': "
 						"%s"),
 					url,
@@ -492,8 +481,6 @@ int Controller::run(const CliArgsParser& args)
 		i++;
 	}
 
-	std::vector<std::string> tags = urlcfg->get_alltags();
-
 	if (!args.do_export() && !args.silent()) {
 		std::cout << _("done.") << std::endl;
 	}
@@ -553,8 +540,8 @@ int Controller::run(const CliArgsParser& args)
 	// hand over the important objects to the View
 	v->set_config_container(&cfg);
 	v->set_keymap(&keys);
-	v->set_tags(tags);
-	v->set_cache(rsscache);
+	v->set_tags(urlcfg->get_alltags());
+	v->set_cache(rsscache.get());
 
 	const auto cmds_to_execute = args.cmds_to_execute();
 	if (cmds_to_execute.size() >= 1) {
@@ -601,12 +588,16 @@ int Controller::run(const CliArgsParser& args)
 				std::cout << strprintf::fmt(_("%" PRIu64 " unreachable feeds found. See "
 							"`cleanup-on-quit` in newsboat(1) for details."), num_feeds)
 					<< std::endl;
+				if (cfg.get_configvalue("cleanup-on-quit") == "nudge") {
+					std::cout << _("Press any key to continue") << std::endl;
+					utils::wait_for_keypress();
+				}
 			}
 		}
 	} catch (const DbException& e) {
 		LOG(Level::USERERROR, "Cleaning up cache failed: %s", e.what());
 		if (!args.silent()) {
-			std::cout << _("failed: ") << e.what() << std::endl;
+			std::cerr << _("failed: ") << e.what() << std::endl;
 			ret = EXIT_FAILURE;
 		}
 	}
@@ -732,11 +723,11 @@ void Controller::replace_feed(RssFeed& oldfeed, RssFeed& newfeed, unsigned int p
 		case EnqueueStatus::OUTPUT_FILENAME_USED_ALREADY:
 			v->get_statusline().show_error(
 				strprintf::fmt(_("Generated filename (%s) is used already."),
-					result.extra_info));
+					result.extra_filename));
 			break;
 		case EnqueueStatus::QUEUE_FILE_OPEN_ERROR:
 			v->get_statusline().show_error(
-				strprintf::fmt(_("Failed to open queue file: %s."), result.extra_info));
+				strprintf::fmt(_("Failed to open queue file: %s."), result.extra_filename));
 			break;
 		}
 	}
@@ -751,13 +742,13 @@ void Controller::replace_feed(RssFeed& oldfeed, RssFeed& newfeed, unsigned int p
 	}
 }
 
-int Controller::import_opml(const std::string& opmlFile,
-	const std::string& urlFile)
+int Controller::import_opml(const Filepath& opmlFile,
+	const Filepath& urlFile)
 {
-	auto urlReader = FileUrlReader(urlFile);
+	FileUrlReader urlReader(urlFile);
 	const auto error_message = urlReader.reload(); // Load existing URLs
 	if (error_message.has_value()) {
-		std::cout << strprintf::fmt(
+		std::cerr << strprintf::fmt(
 				_("Error importing OPML to urls file %s: %s"),
 				urlFile, error_message.value().message)
 			<< std::endl;
@@ -766,7 +757,7 @@ int Controller::import_opml(const std::string& opmlFile,
 
 	const auto import_error = opml::import(opmlFile, urlReader);
 	if (import_error.has_value()) {
-		std::cout << strprintf::fmt(
+		std::cerr << strprintf::fmt(
 				_("An error occurred while parsing %s: %s"),
 				opmlFile,
 				import_error.value())
@@ -885,7 +876,7 @@ void Controller::edit_urls_file()
 
 	std::string cmdline = strprintf::fmt("%s \"%s\"",
 			editor,
-			utils::replace_all(configpaths.url_file(), "\"", "\\\""));
+			utils::replace_all(configpaths.url_file().to_locale_string(), "\"", "\\\""));
 
 	v->push_empty_formaction();
 	Stfl::reset();
@@ -924,49 +915,36 @@ int Controller::execute_commands(const std::vector<std::string>& cmds)
 	return EXIT_SUCCESS;
 }
 
-std::string Controller::write_temporary_item(RssItem& item)
+Filepath Controller::write_temporary_item(RssItem& item)
 {
-	char filename[_POSIX_PATH_MAX];
+	Filepath filename_template;
 	char* tmpdir = getenv("TMPDIR");
 	if (tmpdir != nullptr) {
-		snprintf(filename,
-			sizeof(filename),
-			"%s/newsboat-article.XXXXXX",
-			tmpdir);
+		filename_template = Filepath::from_locale_string(tmpdir);
+		filename_template.push("newsboat-article.XXXXXX"_path);
 	} else {
-		snprintf(filename,
-			sizeof(filename),
-			"/tmp/newsboat-article.XXXXXX");
+		filename_template = "/tmp/newsboat-article.XXXXXX"_path;
 	}
-	int fd = mkstemp(filename);
+
+	auto template_string = filename_template.to_locale_string();
+
+	int fd = mkstemp(template_string.data());
 	if (fd != -1) {
+		const auto filename = Filepath::from_locale_string(template_string);
 		write_item(item, filename);
 		close(fd);
-		return std::string(filename);
+		return filename;
 	} else {
-		return "";
+		return {};
 	}
 }
 
-void Controller::write_item(RssItem& item, const std::string& filename)
+void Controller::write_item(RssItem& item, const Filepath& filename)
 {
-	const std::string save_path = cfg.get_configvalue("save-path");
-	auto spath = save_path.back() == '/' ? save_path : save_path + "/";
+	Filepath save_path = cfg.get_configvalue_as_filepath("save-path");
+	save_path.push(utils::resolve_tilde(filename));
 
-	std::string path;
-	switch (filename[0]) {
-	case '/':
-		path = filename;
-		break;
-	case '~':
-		path = utils::resolve_tilde(filename);
-		break;
-	default:
-		path = spath + filename;
-		break;
-	}
-
-	std::fstream f(path, std::fstream::out);
+	std::fstream f(save_path.to_locale_string(), std::fstream::out);
 	if (!f.is_open()) {
 		throw Exception(errno);
 	}
@@ -979,11 +957,11 @@ void Controller::write_item(RssItem& item, std::ostream& ostr)
 	ostr << item_renderer::to_plain_text(cfg, item) << std::endl;
 }
 
-void Controller::import_read_information(const std::string& readinfofile)
+void Controller::import_read_information(const Filepath& readinfofile)
 {
 	std::vector<std::string> guids;
 
-	std::ifstream f(readinfofile);
+	std::ifstream f(readinfofile.to_locale_string());
 	std::string line;
 	getline(f, line);
 	if (!f.is_open()) {
@@ -996,11 +974,11 @@ void Controller::import_read_information(const std::string& readinfofile)
 	rsscache->mark_items_read_by_guid(guids);
 }
 
-void Controller::export_read_information(const std::string& readinfofile)
+void Controller::export_read_information(const Filepath& readinfofile)
 {
 	std::vector<std::string> guids = rsscache->get_read_item_guids();
 
-	std::fstream f(readinfofile, std::fstream::out);
+	std::fstream f(readinfofile.to_locale_string(), std::fstream::out);
 	if (f.is_open()) {
 		for (const auto& guid : guids) {
 			f << guid << std::endl;
@@ -1012,21 +990,19 @@ void Controller::update_config()
 {
 	v->apply_colors_to_all_formactions();
 
-	if (cfg.get_configvalue("error-log").length() > 0) {
+	const auto error_log_path = cfg.get_configvalue_as_filepath("error-log");
+	if (error_log_path != Filepath{}) {
 		try {
-			logger::set_user_error_logfile(cfg.get_configvalue("error-log"));
+			logger::set_user_error_logfile(error_log_path);
 		} catch (const Exception& e) {
-			const std::string msg =
-				strprintf::fmt("Couldn't open %s: %s",
-					cfg.get_configvalue("error-log"),
-					e.what());
+			const std::string msg = strprintf::fmt("Couldn't open %s: %s", error_log_path, e.what());
 			v->get_statusline().show_error(msg);
 			std::cerr << msg << std::endl;
 		}
 	}
 }
 
-void Controller::load_configfile(const std::string& filename)
+void Controller::load_configfile(const Filepath& filename)
 {
 	if (cfgparser.parse_file(filename)) {
 		update_config();
@@ -1037,7 +1013,7 @@ void Controller::load_configfile(const std::string& filename)
 	}
 }
 
-void Controller::dump_config(const std::string& filename) const
+void Controller::dump_config(const Filepath& filename) const
 {
 	std::vector<std::string> configlines;
 	cfg.dump_config(configlines);
@@ -1048,7 +1024,7 @@ void Controller::dump_config(const std::string& filename) const
 	filters.dump_config(configlines);
 	colorman.dump_config(configlines);
 	rxman.dump_config(configlines);
-	std::fstream f(filename, std::fstream::out);
+	std::fstream f(filename.to_locale_string(), std::fstream::out);
 	if (f.is_open()) {
 		for (const auto& line : configlines) {
 			f << line << std::endl;
