@@ -5,22 +5,20 @@
 
 #include "config.h"
 #include "fmtstrformatter.h"
-#include "listformatter.h"
+#include "stflrichtext.h"
 #include "strprintf.h"
 #include "utils.h"
 #include "view.h"
 
 namespace newsboat {
 
-DialogsFormAction::DialogsFormAction(View* vv,
+DialogsFormAction::DialogsFormAction(View& vv,
 	std::string formstr,
 	ConfigContainer* cfg, RegexManager& r)
 	: ListFormAction(vv, "dialoglist", formstr, "dialogs", cfg, r)
 {
 }
 
-DialogsFormAction::~DialogsFormAction() {}
-
 void DialogsFormAction::init()
 {
 	set_keymap_hints();
@@ -33,20 +31,20 @@ void DialogsFormAction::prepare()
 	if (do_redraw) {
 		update_heading();
 
-		auto render_line = [this](std::uint32_t line, std::uint32_t width) -> std::string {
+		auto render_line = [this](std::uint32_t line, std::uint32_t width) -> StflRichText {
 			(void)width;
-			const auto formaction_names = v->get_formaction_names();
+			const auto formaction_names = v.get_formaction_names();
 			const auto& fa = formaction_names[line];
 			const bool is_current_formaction =
-			v->get_formaction(fa.first) == get_parent_formaction();
-			return utils::quote_for_stfl(
+			v.get_formaction(fa.first) == get_parent_formaction();
+			return StflRichText::from_plaintext(
 				strprintf::fmt("%4u %s %s",
 					line + 1,
 					is_current_formaction ? "*" : " ",
 					fa.second));
 		};
 
-		list.invalidate_list_content(v->get_formaction_names().size(), render_line);
+		list.invalidate_list_content(v.get_formaction_names().size(), render_line);
 
 		do_redraw = false;
 	}
@@ -60,10 +58,10 @@ void DialogsFormAction::update_heading()
 	FmtStrFormatter fmt;
 	fmt.register_fmt('N', PROGRAM_NAME);
 	fmt.register_fmt('V', utils::program_version());
-	set_value("head", fmt.do_format(title_format, width));
+	set_title(fmt.do_format(title_format, width));
 }
 
-const std::vector<KeyMapHintEntry>& DialogsFormAction::get_keymap_hint() const
+std::vector<KeyMapHintEntry> DialogsFormAction::get_keymap_hint() const
 {
 	static const std::vector<KeyMapHintEntry> hints = {{OP_QUIT, _("Close")},
 		{OP_OPEN, _("Goto Dialog")},
@@ -79,16 +77,16 @@ bool DialogsFormAction::process_operation(Operation op,
 	switch (op) {
 	case OP_OPEN: {
 		const unsigned int pos = list.get_position();
-		v->set_current_formaction(pos);
+		v.set_current_formaction(pos);
 	}
 	break;
 	case OP_CLOSEDIALOG: {
 		const unsigned int pos = list.get_position();
 		if (pos != 0) {
-			v->remove_formaction(pos);
+			v.remove_formaction(pos);
 			do_redraw = true;
 		} else {
-			v->get_statusline().show_error(
+			v.get_statusline().show_error(
 				_("Error: you can't remove the feed list!"));
 		}
 	}
@@ -100,11 +98,10 @@ bool DialogsFormAction::process_operation(Operation op,
 		list.move_down(cfg->get_configvalue_as_bool("wrap-scroll"));
 		break;
 	case OP_QUIT:
-		v->pop_current_formaction();
+		v.pop_current_formaction();
 		break;
 	default:
-		ListFormAction::process_operation(op, args, bindingType);
-		break;
+		return ListFormAction::process_operation(op, args, bindingType);
 	}
 	return true;
 }
@@ -118,10 +115,10 @@ void DialogsFormAction::handle_cmdline(const std::string& cmd)
 {
 	unsigned int idx = 0;
 	if (1 == sscanf(cmd.c_str(), "%u", &idx)) {
-		if (idx >= 1 && idx <= v->formaction_stack_size()) {
+		if (idx >= 1 && idx <= v.formaction_stack_size()) {
 			list.set_position(idx - 1);
 		} else {
-			v->get_statusline().show_error(_("Invalid position!"));
+			v.get_statusline().show_error(_("Invalid position!"));
 		}
 	} else {
 		FormAction::handle_cmdline(cmd);
