@@ -26,8 +26,10 @@ FormAction::FormAction(View& vv, std::string formstr, ConfigContainer* cfg)
 	, head_line(f, "head")
 	, msg_line(f, "msg")
 	, qna_prompt_line(f, "qna_prompt")
-	, finish_operation(OP_NIL)
+	, qna_input(f, "qna")
+	, qna_finish_operation(QnaFinishAction::None)
 	, qna_history(nullptr)
+	, tab_count(0)
 {
 	if (cfg->get_configvalue_as_bool("show-keymap-hint") == false) {
 		set_value("showhint", "0");
@@ -51,6 +53,12 @@ FormAction::FormAction(View& vv, std::string formstr, ConfigContainer* cfg)
 	valid_cmds.push_back("exec");
 }
 
+void FormAction::report_unhandled_operation(Operation op)
+{
+	set_status(strprintf::fmt(_("Operation %s not handled in %s"), KeyMap::get_op_name(op),
+			id()));
+}
+
 void FormAction::set_keymap_hints()
 {
 	set_value("help", v.get_keymap()->prepare_keymap_hint(this->get_keymap_hint(),
@@ -92,7 +100,7 @@ void FormAction::start_cmdline(std::string default_value)
 	std::vector<QnaPair> qna;
 	qna.push_back(QnaPair(":", default_value));
 	v.inside_cmdline(true);
-	this->start_qna(qna, OP_INT_END_CMDLINE, &FormAction::cmdlinehistory);
+	this->start_qna(qna, QnaFinishAction::RunCmdLine, &FormAction::cmdlinehistory);
 }
 
 bool FormAction::process_op(Operation op,
@@ -107,7 +115,7 @@ bool FormAction::process_op(Operation op,
 	case OP_CMDLINE:
 		start_cmdline();
 		break;
-	case OP_INT_SET:
+	case OP_SET:
 		switch (bindingType) {
 		case BindingType::Bind:
 		case BindingType::Macro:
@@ -127,7 +135,7 @@ bool FormAction::process_op(Operation op,
 			return false;
 		case BindingType::BindKey:
 			LOG(Level::WARN,
-				"FormAction::process_op: got OP_INT_SET, but from a bind-key which does not support arguments");
+				"FormAction::process_op: got OP_SET, but from a bind-key which does not support arguments");
 			break;
 		}
 		break;
@@ -244,9 +252,16 @@ void FormAction::handle_set(const std::vector<std::string>& args)
 				args[0],
 				utils::quote_if_necessary(cfg->get_configvalue(args[0]))));
 	} else if (args.size() == 2) {
-		std::string result = ConfigParser::evaluate_backticks(args[1]);
-		utils::trim_end(result);
-		cfg->set_configvalue(args[0], result);
+		std::string value = ConfigParser::evaluate_backticks(args[1]);
+		utils::trim_end(value);
+		const auto& key = args[0];
+		const auto result = cfg->set_configvalue(key, value);
+		if (!result) {
+			v.get_statusline().show_error(strprintf::fmt(_("error setting '%s' to '%s': %s"),
+					key,
+					value,
+					result.error()));
+		}
 		// because some configuration value might have changed something UI-related
 		set_redraw(true);
 	} else {
@@ -269,9 +284,8 @@ void FormAction::handle_source(const std::vector<std::string>& args)
 	} else {
 		for (const auto& param : args) {
 			try {
-				v.get_ctrl()->load_configfile(
-					utils::resolve_tilde(
-						param));
+				const auto path = Filepath::from_locale_string(param);
+				v.get_ctrl().load_configfile(utils::resolve_tilde(path));
 			} catch (const ConfigException& ex) {
 				v.get_statusline().show_error(ex.what());
 				break;
@@ -285,8 +299,8 @@ void FormAction::handle_dumpconfig(const std::vector<std::string>& args)
 	if (args.size() != 1) {
 		v.get_statusline().show_error(_("usage: dumpconfig <file>"));
 	} else {
-		v.get_ctrl()->dump_config(
-			utils::resolve_tilde(args[0]));
+		const auto path = Filepath::from_locale_string(args[0]);
+		v.get_ctrl().dump_config(utils::resolve_tilde(path));
 		v.get_statusline().show_message(strprintf::fmt(
 				_("Saved configuration to %s"),
 				args[0]));
@@ -364,9 +378,10 @@ bool FormAction::handle_list_operations(ListWidget& list, Operation op)
 		list.scroll_halfpage_down(cfg->get_configvalue_as_bool("wrap-scroll"));
 		break;
 	default:
+		report_unhandled_operation(op);
 		return false;
 	}
-	return false;
+	return true;
 }
 
 bool FormAction::handle_textview_operations(TextviewWidget& textview, Operation op)
@@ -397,6 +412,7 @@ bool FormAction::handle_textview_operations(TextviewWidget& textview, Operation
 		textview.scroll_halfpage_down();
 		break;
 	default:
+		report_unhandled_operation(op);
 		return false;
 	}
 	return true;
@@ -420,7 +436,7 @@ bool FormAction::handle_single_argument_set(std::string argument)
 }
 
 void FormAction::start_qna(const std::vector<QnaPair>& prompts,
-	Operation finish_op,
+	QnaFinishAction finish_op,
 	History* h)
 {
 	/*
@@ -440,7 +456,7 @@ void FormAction::start_qna(const std::vector<QnaPair>& prompts,
 	 */
 	qna_prompts = prompts;
 	qna_responses.clear();
-	finish_operation = finish_op;
+	qna_finish_operation = finish_op;
 	qna_history = h;
 	v.inside_qna(true);
 	start_next_question();
@@ -448,7 +464,7 @@ void FormAction::start_qna(const std::vector<QnaPair>& prompts,
 
 void FormAction::finish_qna_question()
 {
-	qna_responses.push_back(get_value("qna_value"));
+	qna_responses.push_back(qna_input.get_value());
 	start_next_question();
 }
 
@@ -457,7 +473,7 @@ void FormAction::cancel_qna()
 	LOG(Level::DEBUG, "FormAction::cancel_qna");
 
 	qna_prompt_line.hide();
-	f.set("show_qna_input", "0");
+	qna_input.hide();
 	msg_line.show();
 	msg_line.set_text("");
 
@@ -471,8 +487,8 @@ void FormAction::qna_next_history()
 {
 	if (qna_history) {
 		std::string entry = qna_history->next_line();
-		set_value("qna_value", entry);
-		set_value("qna_value_pos", std::to_string(entry.length()));
+		qna_input.set_value(entry);
+		qna_input.set_position(entry.length());
 	}
 }
 
@@ -480,12 +496,106 @@ void FormAction::qna_previous_history()
 {
 	if (qna_history) {
 		std::string entry = qna_history->previous_line();
-		set_value("qna_value", entry);
-		set_value("qna_value_pos", std::to_string(entry.length()));
+		qna_input.set_value(entry);
+		qna_input.set_position(entry.length());
 	}
 }
 
-void FormAction::finished_qna(Operation op)
+void FormAction::clear_line()
+{
+	qna_input.set_value("");
+	qna_input.set_position(0);
+}
+
+void FormAction::clear_eol()
+{
+	unsigned int pos = qna_input.get_position();
+	std::string val = qna_input.get_value();
+	val.erase(pos, val.length());
+	qna_input.set_value(val);
+	qna_input.set_position(val.length());
+	LOG(Level::DEBUG, "View::clear_eol: cleared to end of line");
+}
+
+void FormAction::delete_word()
+{
+	std::string::size_type curpos = qna_input.get_position();
+	std::string val = qna_input.get_value();
+	std::string::size_type firstpos = curpos;
+	LOG(Level::DEBUG, "View::delete_word: before val = %s", val);
+	if (firstpos >= val.length() || ::isspace(val[firstpos])) {
+		if (firstpos != 0 && firstpos >= val.length()) {
+			firstpos = val.length() - 1;
+		}
+		while (firstpos > 0 && ::isspace(val[firstpos])) {
+			--firstpos;
+		}
+	}
+	while (firstpos > 0 && !::isspace(val[firstpos])) {
+		--firstpos;
+	}
+	if (firstpos != 0) {
+		firstpos++;
+	}
+	val.erase(firstpos, curpos - firstpos);
+	LOG(Level::DEBUG, "View::delete_word: after val = %s", val);
+	qna_input.set_value(val);
+	qna_input.set_position(firstpos);
+}
+
+void FormAction::handle_cmdline_completion()
+{
+	std::string fragment = qna_input.get_value();
+	if (fragment != last_fragment || fragment == "") {
+		last_fragment = fragment;
+		suggestions = get_suggestions(fragment);
+		tab_count = 0;
+	}
+	tab_count++;
+	std::string suggestion;
+	switch (suggestions.size()) {
+	case 0:
+		LOG(Level::DEBUG, "FormAction::handle_cmdline_completion: found no suggestion for `%s'",
+			fragment);
+		// direct call to ncurses - we beep to signal that there is no suggestion available, just like vim
+		::beep();
+		return;
+	case 1:
+		suggestion = suggestions[0];
+		break;
+	default:
+		suggestion = suggestions[(tab_count - 1) % suggestions.size()];
+		break;
+	}
+	qna_input.set_value(suggestion);
+	qna_input.set_position(suggestion.length());
+	last_fragment = suggestion;
+}
+
+void FormAction::handle_qna_event(std::string event, bool inside_cmd)
+{
+	if (event == "ESC") {
+		cancel_qna();
+	} else if (inside_cmd && event == "TAB") {
+		handle_cmdline_completion();
+	} else if (event == "UP") {
+		qna_previous_history();
+	} else if (event == "DOWN") {
+		qna_next_history();
+	} else if (event == "ENTER") {
+		finish_qna_question();
+	} else if (event == "^U") {
+		clear_line();
+	} else if (event == "^K") {
+		clear_eol();
+	} else if (event == "^G") {
+		cancel_qna();
+	} else if (event == "^W") {
+		delete_word();
+	}
+}
+
+void FormAction::finished_qna(QnaFinishAction op)
 {
 	v.inside_qna(false);
 	v.inside_cmdline(false);
@@ -500,7 +610,7 @@ void FormAction::finished_qna(Operation op)
 	 * 	- run operation (in this case, save the bookmark)
 	 * 	- signal success (or failure) to the user
 	 */
-	case OP_INT_BM_END: {
+	case QnaFinishAction::Bookmark: {
 		assert(qna_responses.size() == 4 &&
 			qna_prompts.size() == 0); // everything must be answered
 		v.get_statusline().show_message(_("Saving bookmark..."));
@@ -520,7 +630,7 @@ void FormAction::finished_qna(Operation op)
 		}
 	}
 	break;
-	case OP_INT_END_CMDLINE: {
+	case QnaFinishAction::RunCmdLine: {
 		f.set_focus(main_widget());
 		std::string cmdline = qna_responses[0];
 		FormAction::cmdlinehistory.add_line(cmdline);
@@ -573,7 +683,7 @@ void FormAction::start_bookmark_qna(const std::string& default_title,
 
 		// if url or title is missing, abort autopilot and ask user
 		if (default_url.empty() || title.empty()) {
-			start_qna(prompts, OP_INT_BM_END);
+			start_qna(prompts, QnaFinishAction::Bookmark);
 		} else {
 			v.get_statusline().show_message(_("Saving bookmark on autopilot..."));
 			std::string retval = bookmark(default_url,
@@ -593,7 +703,7 @@ void FormAction::start_bookmark_qna(const std::string& default_title,
 			}
 		}
 	} else {
-		start_qna(prompts, OP_INT_BM_END);
+		start_qna(prompts, QnaFinishAction::Bookmark);
 	}
 }
 
@@ -636,18 +746,17 @@ void FormAction::start_next_question()
 	 */
 	if (qna_prompts.size() > 0) {
 		qna_prompt_line.set_text(qna_prompts[0].first);
-		f.set("qna_value", qna_prompts[0].second);
+		qna_input.set_value(qna_prompts[0].second);
 
 		qna_prompt_line.show();
-		f.set("show_qna_input", "1");
+		qna_input.show();
 		msg_line.hide();
 
 		f.set_focus("qnainput");
 
 		// Set position to 0 and back to ensure that the text is visible
 		draw_form();
-		set_value("qna_value_pos",
-			std::to_string(qna_prompts[0].second.length()));
+		qna_input.set_position(qna_prompts[0].second.length());
 
 		qna_prompts.erase(qna_prompts.begin());
 	} else {
@@ -657,25 +766,25 @@ void FormAction::start_next_question()
 		 * finished_qna() method.
 		 */
 		qna_prompt_line.hide();
-		f.set("show_qna_input", "0");
+		qna_input.hide();
 		msg_line.show();
 		msg_line.set_text("");
 
 		f.set_focus(main_widget());
 
-		this->finished_qna(finish_operation);
+		this->finished_qna(qna_finish_operation);
 	}
 }
 
-void FormAction::load_histories(const std::string& searchfile,
-	const std::string& cmdlinefile)
+void FormAction::load_histories(const Filepath& searchfile,
+	const Filepath& cmdlinefile)
 {
 	searchhistory.load_from_file(searchfile);
 	cmdlinehistory.load_from_file(cmdlinefile);
 }
 
-void FormAction::save_histories(const std::string& searchfile,
-	const std::string& cmdlinefile,
+void FormAction::save_histories(const Filepath& searchfile,
+	const Filepath& cmdlinefile,
 	unsigned int limit)
 {
 	searchhistory.save_to_file(searchfile, limit);
