@@ -17,7 +17,6 @@ HelpFormAction::HelpFormAction(View& vv,
 	ConfigContainer* cfg,
 	const std::string& ctx)
 	: FormAction(vv, formstr, cfg)
-	, quit(false)
 	, apply_search(false)
 	, context(ctx)
 	, textview("helptext", FormAction::f)
@@ -28,6 +27,7 @@ bool HelpFormAction::process_operation(Operation op,
 	const std::vector<std::string>& /* args */,
 	BindingType /*bindingType*/)
 {
+	bool quit = false;
 	bool hardquit = false;
 	switch (op) {
 	case OP_QUIT:
@@ -39,7 +39,7 @@ bool HelpFormAction::process_operation(Operation op,
 	case OP_SEARCH: {
 		std::vector<QnaPair> qna;
 		qna.push_back(QnaPair(_("Search for: "), ""));
-		this->start_qna(qna, OP_INT_START_SEARCH, &searchhistory);
+		this->start_qna(qna, QnaFinishAction::Search, &searchhistory);
 	}
 	break;
 	case OP_CLEARFILTER:
@@ -47,10 +47,7 @@ bool HelpFormAction::process_operation(Operation op,
 		do_redraw = true;
 		break;
 	default:
-		if (handle_textview_operations(textview, op)) {
-			break;
-		}
-		break;
+		return handle_textview_operations(textview, op);
 	}
 	if (hardquit) {
 		while (v.formaction_stack_size() > 0) {
@@ -75,102 +72,77 @@ void HelpFormAction::prepare()
 		fmt.register_fmt('V', utils::program_version());
 		set_title(fmt.do_format(cfg->get_configvalue("help-title-format"), width));
 
-		const auto descs = v.get_keymap()->get_keymap_descriptions(context);
+		ListFormatter listfmt;
 
 		std::vector<std::string> colors = utils::tokenize(
 				cfg->get_configvalue("search-highlight-colors"), " ");
 		set_value("highlight", make_colorstring(colors));
-		ListFormatter listfmt;
 
-		std::vector<KeyMapDesc> syskey_descriptions;
-		std::vector<KeyMapDesc> unbound_descriptions;
-		std::vector<KeyMapDesc> bound_descriptions;
-
-		for (const auto& desc : descs) {
-			if (desc.flags & KM_SYSKEYS) {
-				syskey_descriptions.push_back(desc);
-			} else if (desc.key.get_key().empty()) {
-				unbound_descriptions.push_back(desc);
-			} else {
-				bound_descriptions.push_back(desc);
-			}
-		}
-
-		const auto should_be_visible = [&](const KeyMapDesc& desc) {
+		const auto should_bind_be_visible = [&](const HelpBindInfo& bind) {
 			return !apply_search
-				|| strcasestr(desc.key.to_bindkey_string().c_str(), searchphrase.c_str()) != nullptr
-				|| strcasestr(desc.cmd.c_str(), searchphrase.c_str()) != nullptr
-				|| strcasestr(desc.desc.c_str(), searchphrase.c_str()) != nullptr;
+				|| strcasestr(bind.key_sequence.c_str(), searchphrase.c_str()) != nullptr
+				|| strcasestr(bind.op_name.value_or("").c_str(), searchphrase.c_str()) != nullptr
+				|| strcasestr(bind.description.c_str(), searchphrase.c_str()) != nullptr;
+		};
+
+		const auto should_unused_be_visible = [&](const UnboundAction& unbound) {
+			return !apply_search
+				|| strcasestr(unbound.op_name.c_str(), searchphrase.c_str()) != nullptr
+				|| strcasestr(unbound.description.c_str(), searchphrase.c_str()) != nullptr;
+		};
+
+		const auto should_macro_be_visible = [&](const HelpMacroInfo& macro) {
+			return !apply_search
+				|| strcasestr(macro.key_sequence.c_str(), searchphrase.c_str()) != nullptr
+				|| strcasestr(macro.description.c_str(), searchphrase.c_str()) != nullptr;
 		};
 
-		std::string highlighted_searchphrase = strprintf::fmt("<hl>%s</>", searchphrase);
 		const auto apply_highlights = [&](const std::string& line) {
+			auto text = StflRichText::from_plaintext(line);
 			if (apply_search && searchphrase.length() > 0) {
-				return utils::replace_all(line, searchphrase, highlighted_searchphrase);
+				text.highlight_searchphrase(searchphrase);
 			}
-			return line;
+			return text;
 		};
 
-		for (const auto& desc : bound_descriptions) {
-			if (should_be_visible(desc)) {
-				auto line = strprintf::fmt("%-15s %-23s %s",
-						desc.key.to_bindkey_string(),
-						desc.cmd,
-						desc.desc);
-				line = utils::quote_for_stfl(line);
-				line = apply_highlights(line);
-				listfmt.add_line(StflRichText::from_quoted(line));
+		const auto help_info = v.get_keymap()->get_help_info(context);
+
+		const auto& bindings = help_info.bindings;
+		for (const auto& desc : bindings) {
+			if (should_bind_be_visible(desc)) {
+				const std::string line = strprintf::fmt("%-15s %-23s %s",
+						desc.key_sequence,
+						desc.op_name.value_or(""),
+						desc.description);
+				listfmt.add_line(apply_highlights(line));
 			}
 		}
 
-		if (!syskey_descriptions.empty()) {
-			listfmt.add_line(StflRichText::from_plaintext(""));
-			listfmt.add_line(StflRichText::from_plaintext(_("Generic bindings:")));
-			listfmt.add_line(StflRichText::from_plaintext(""));
-
-			for (const auto& desc : syskey_descriptions) {
-				if (should_be_visible(desc)) {
-					auto line = strprintf::fmt("%-15s %-23s %s",
-							desc.key.to_bindkey_string(),
-							desc.cmd,
-							desc.desc);
-					line = utils::quote_for_stfl(line);
-					line = apply_highlights(line);
-					listfmt.add_line(StflRichText::from_quoted(line));
-				}
-			}
-		}
-
-		if (!unbound_descriptions.empty()) {
+		const auto& unused_actions = help_info.unused;
+		if (!unused_actions.empty()) {
 			listfmt.add_line(StflRichText::from_plaintext(""));
 			listfmt.add_line(StflRichText::from_plaintext(_("Unbound functions:")));
 			listfmt.add_line(StflRichText::from_plaintext(""));
 
-			for (const auto& desc : unbound_descriptions) {
-				if (should_be_visible(desc)) {
-					std::string line = strprintf::fmt("%-39s %s", desc.cmd, desc.desc);
-					line = utils::quote_for_stfl(line);
-					line = apply_highlights(line);
-					listfmt.add_line(StflRichText::from_quoted(line));
+			for (const auto& desc : unused_actions) {
+				if (should_unused_be_visible(desc)) {
+					const std::string line = strprintf::fmt("%-39s %s", desc.op_name, desc.description);
+					listfmt.add_line(apply_highlights(line));
 				}
 			}
 		}
 
-		const auto macros = v.get_keymap()->get_macro_descriptions();
+		const auto& macros = help_info.macros;
 		if (!macros.empty()) {
 			listfmt.add_line(StflRichText::from_plaintext(""));
 			listfmt.add_line(StflRichText::from_plaintext(_("Macros:")));
 			listfmt.add_line(StflRichText::from_plaintext(""));
 
 			for (const auto& macro : macros) {
-				const std::string key = macro.first.to_bindkey_string();
-				const std::string description = macro.second.description;
-
-				// "macro-prefix" is not translated because it refers to an operation name
-				std::string line = strprintf::fmt("<macro-prefix>%s  %s", key, description);
-				line = utils::quote_for_stfl(line);
-				line = apply_highlights(line);
-				listfmt.add_line(StflRichText::from_quoted(line));
+				if (should_macro_be_visible(macro)) {
+					const std::string line = strprintf::fmt("%s  %s", macro.key_sequence, macro.description);
+					listfmt.add_line(apply_highlights(line));
+				}
 			}
 		}
 
@@ -178,7 +150,6 @@ void HelpFormAction::prepare()
 
 		do_redraw = false;
 	}
-	quit = false;
 }
 
 void HelpFormAction::init()
@@ -196,11 +167,11 @@ std::vector<KeyMapHintEntry> HelpFormAction::get_keymap_hint() const
 	return hints;
 }
 
-void HelpFormAction::finished_qna(Operation op)
+void HelpFormAction::finished_qna(QnaFinishAction op)
 {
 	v.inside_qna(false);
 	switch (op) {
-	case OP_INT_START_SEARCH:
+	case QnaFinishAction::Search:
 		searchphrase = qna_responses[0];
 		apply_search = true;
 		do_redraw = true;
