@@ -6,7 +6,9 @@
 #include <vector>
 #include <thread>
 
-#include "config.h"
+#include "curldatareceiver.h"
+#include "curlhandle.h"
+#include "logger.h"
 #include "strprintf.h"
 #include "utils.h"
 
@@ -22,15 +24,9 @@
 
 namespace newsboat {
 
-InoreaderApi::InoreaderApi(ConfigContainer* c)
+InoreaderApi::InoreaderApi(ConfigContainer& c)
 	: RemoteApi(c)
 {
-	// TODO
-}
-
-InoreaderApi::~InoreaderApi()
-{
-	// TODO
 }
 
 bool InoreaderApi::authenticate()
@@ -40,24 +36,16 @@ bool InoreaderApi::authenticate()
 	return auth != "";
 }
 
-static size_t my_write_data(void* buffer, size_t size, size_t nmemb,
-	void* userp)
-{
-	std::string* pbuf = static_cast<std::string*>(userp);
-	pbuf->append(static_cast<const char*>(buffer), size * nmemb);
-	return size * nmemb;
-}
-
 std::string InoreaderApi::retrieve_auth()
 {
-	CURL* handle = curl_easy_init();
+	CurlHandle handle;
 	Credentials cred = get_credentials("inoreader", "Inoreader");
 	if (cred.user.empty() || cred.pass.empty()) {
 		return "";
 	}
 
-	char* username = curl_easy_escape(handle, cred.user.c_str(), 0);
-	char* password = curl_easy_escape(handle, cred.pass.c_str(), 0);
+	char* username = curl_easy_escape(handle.ptr(), cred.user.c_str(), 0);
+	char* password = curl_easy_escape(handle.ptr(), cred.pass.c_str(), 0);
 
 	std::string postcontent =
 		strprintf::fmt("Email=%s&Passwd=%s", username, password);
@@ -65,20 +53,19 @@ std::string InoreaderApi::retrieve_auth()
 	curl_free(username);
 	curl_free(password);
 
-	std::string result;
-
 	curl_slist* list = NULL;
 	list = add_app_headers(list);
 
 	utils::set_common_curl_options(handle, cfg);
-	curl_easy_setopt(handle, CURLOPT_WRITEFUNCTION, my_write_data);
-	curl_easy_setopt(handle, CURLOPT_WRITEDATA, &result);
-	curl_easy_setopt(handle, CURLOPT_POSTFIELDS, postcontent.c_str());
-	curl_easy_setopt(handle, CURLOPT_URL, INOREADER_LOGIN);
-	curl_easy_perform(handle);
-	curl_easy_cleanup(handle);
+	curl_easy_setopt(handle.ptr(), CURLOPT_POSTFIELDS, postcontent.c_str());
+	curl_easy_setopt(handle.ptr(), CURLOPT_URL, INOREADER_LOGIN);
+
+	auto curlDataReceiver = CurlDataReceiver::register_data_handler(handle);
+
+	curl_easy_perform(handle.ptr());
 	curl_slist_free_all(list);
 
+	const std::string result = curlDataReceiver->get_data();
 	std::vector<std::string> lines = utils::tokenize(result);
 	for (const auto& line : lines) {
 		LOG(Level::DEBUG,
@@ -99,19 +86,19 @@ std::vector<TaggedFeedUrl> InoreaderApi::get_subscribed_urls()
 	std::vector<TaggedFeedUrl> urls;
 	curl_slist* custom_headers{};
 
-	CURL* handle = curl_easy_init();
-	std::string result;
+	CurlHandle handle;
 	add_custom_headers(&custom_headers);
-	curl_easy_setopt(handle, CURLOPT_HTTPHEADER, custom_headers);
+	curl_easy_setopt(handle.ptr(), CURLOPT_HTTPHEADER, custom_headers);
 
 	utils::set_common_curl_options(handle, cfg);
-	curl_easy_setopt(handle, CURLOPT_WRITEFUNCTION, my_write_data);
-	curl_easy_setopt(handle, CURLOPT_WRITEDATA, &result);
-	curl_easy_setopt(handle, CURLOPT_URL, INOREADER_SUBSCRIPTION_LIST);
-	curl_easy_perform(handle);
-	curl_easy_cleanup(handle);
+	curl_easy_setopt(handle.ptr(), CURLOPT_URL, INOREADER_SUBSCRIPTION_LIST);
+
+	auto curlDataReceiver = CurlDataReceiver::register_data_handler(handle);
+
+	curl_easy_perform(handle.ptr());
 	curl_slist_free_all(custom_headers);
 
+	const std::string result = curlDataReceiver->get_data();
 	LOG(Level::DEBUG,
 		"InoreaderApi::get_subscribed_urls: document = %s",
 		result);
@@ -140,12 +127,20 @@ std::vector<TaggedFeedUrl> InoreaderApi::get_subscribed_urls()
 
 		json_object_object_get_ex(sub, "id", &node);
 		const char* id = json_object_get_string(node);
-		char* id_uenc = curl_easy_escape(handle, id, 0);
+		if (id == nullptr) {
+			LOG(Level::WARN, "Skipping a subscription without an id");
+			continue;
+		}
+		char* id_uenc = curl_easy_escape(handle.ptr(), id, 0);
 
 		json_object_object_get_ex(sub, "title", &node);
 		const char* title = json_object_get_string(node);
-
-		tags.push_back(std::string("~") + title);
+		if (title != nullptr) {
+			tags.push_back(std::string("~") + title);
+		} else {
+			LOG(Level::WARN, "Subscription has no title, so let's call it \"%i\"", i);
+			tags.push_back(std::string("~") + std::to_string(i));
+		}
 
 		json_object_object_get_ex(sub, "categories", &node);
 		struct array_list* categories = json_object_get_array(node);
@@ -159,13 +154,17 @@ std::vector<TaggedFeedUrl> InoreaderApi::get_subscribed_urls()
 			json_object* label_node{};
 			json_object_object_get_ex(cat, "label", &label_node);
 			const char* label = json_object_get_string(label_node);
+			if (label == nullptr) {
+				LOG(Level::WARN, "Skipping subscription's label whose name is a null value");
+				continue;
+			}
 			tags.push_back(std::string(label));
 		}
 
 		auto url = strprintf::fmt("%s%s?n=%u",
 				INOREADER_FEED_PREFIX,
 				id_uenc,
-				cfg->get_configvalue_as_int("inoreader-min-items"));
+				cfg.get_configvalue_as_int("inoreader-min-items"));
 		urls.push_back(TaggedFeedUrl(url, tags));
 
 		curl_free(id_uenc);
@@ -245,28 +244,20 @@ bool InoreaderApi::update_article_flags(const std::string& inoflags,
 	const std::string& newflags,
 	const std::string& guid)
 {
-	std::string star_flag = cfg->get_configvalue("inoreader-flag-star");
-	std::string share_flag = cfg->get_configvalue("inoreader-flag-share");
+	std::string star_flag = cfg.get_configvalue("inoreader-flag-star");
+	std::string share_flag = cfg.get_configvalue("inoreader-flag-share");
 	bool success = true;
 
 	if (star_flag.length() > 0) {
-		if (strchr(inoflags.c_str(), star_flag[0]) == nullptr &&
-			strchr(newflags.c_str(), star_flag[0]) != nullptr) {
-			success = star_article(guid, true);
-		} else if (strchr(inoflags.c_str(), star_flag[0]) != nullptr &&
-			strchr(newflags.c_str(), star_flag[0]) == nullptr) {
-			success = star_article(guid, false);
-		}
+		update_flag(inoflags, newflags, star_flag[0], [&](bool added) {
+			success = star_article(guid, added);
+		});
 	}
 
 	if (share_flag.length() > 0) {
-		if (strchr(inoflags.c_str(), share_flag[0]) == nullptr &&
-			strchr(newflags.c_str(), share_flag[0]) != nullptr) {
-			success = share_article(guid, true);
-		} else if (strchr(inoflags.c_str(), share_flag[0]) != nullptr &&
-			strchr(newflags.c_str(), share_flag[0]) == nullptr) {
-			success = share_article(guid, false);
-		}
+		update_flag(inoflags, newflags, share_flag[0], [&](bool added) {
+			success = share_article(guid, added);
+		});
 	}
 
 	return success;
@@ -315,21 +306,21 @@ bool InoreaderApi::share_article(const std::string& guid, bool share)
 std::string InoreaderApi::post_content(const std::string& url,
 	const std::string& postdata)
 {
-	std::string result;
 	curl_slist* custom_headers{};
 
-	CURL* handle = curl_easy_init();
+	CurlHandle handle;
 	utils::set_common_curl_options(handle, cfg);
 	add_custom_headers(&custom_headers);
-	curl_easy_setopt(handle, CURLOPT_HTTPHEADER, custom_headers);
-	curl_easy_setopt(handle, CURLOPT_WRITEFUNCTION, my_write_data);
-	curl_easy_setopt(handle, CURLOPT_WRITEDATA, &result);
-	curl_easy_setopt(handle, CURLOPT_POSTFIELDS, postdata.c_str());
-	curl_easy_setopt(handle, CURLOPT_URL, url.c_str());
-	curl_easy_perform(handle);
-	curl_easy_cleanup(handle);
+	curl_easy_setopt(handle.ptr(), CURLOPT_HTTPHEADER, custom_headers);
+	curl_easy_setopt(handle.ptr(), CURLOPT_POSTFIELDS, postdata.c_str());
+	curl_easy_setopt(handle.ptr(), CURLOPT_URL, url.c_str());
+
+	auto curlDataReceiver = CurlDataReceiver::register_data_handler(handle);
+
+	curl_easy_perform(handle.ptr());
 	curl_slist_free_all(custom_headers);
 
+	const std::string result = curlDataReceiver->get_data();
 	LOG(Level::DEBUG,
 		"InoreaderApi::post_content: url = %s postdata = %s result = "
 		"%s",
@@ -344,12 +335,12 @@ curl_slist* InoreaderApi::add_app_headers(curl_slist* headers)
 {
 	const auto app_id = strprintf::fmt(
 			"AppId: %s",
-			cfg->get_configvalue("inoreader-app-id"));
+			cfg.get_configvalue("inoreader-app-id"));
 	headers = curl_slist_append(headers, app_id.c_str());
 
 	const auto app_key = strprintf::fmt(
 			"AppKey: %s",
-			cfg->get_configvalue("inoreader-app-key"));
+			cfg.get_configvalue("inoreader-app-key"));
 	headers = curl_slist_append(headers, app_key.c_str());
 
 	return headers;
