@@ -2,7 +2,6 @@
 
 #include "config.h"
 #include "configcontainer.h"
-#include "fileurlreader.h"
 #include "logger.h"
 #include "remoteapi.h"
 #include "utils.h"
@@ -10,7 +9,7 @@
 namespace newsboat {
 
 InoreaderUrlReader::InoreaderUrlReader(ConfigContainer* c,
-	const std::string& url_file,
+	const Filepath& url_file,
 	RemoteApi* a)
 	: cfg(c)
 	, file(url_file)
@@ -38,11 +37,10 @@ InoreaderUrlReader::~InoreaderUrlReader() {}
 		tags[(url)] = tmptags;        \
 	} while (0)
 
-nonstd::optional<utils::ReadTextFileError> InoreaderUrlReader::reload()
+std::optional<utils::ReadTextFileError> InoreaderUrlReader::reload()
 {
 	urls.clear();
 	tags.clear();
-	alltags.clear();
 
 	if (cfg->get_configvalue_as_bool("inoreader-show-special-feeds")) {
 		std::vector<std::string> tmptags;
@@ -55,24 +53,7 @@ nonstd::optional<utils::ReadTextFileError> InoreaderUrlReader::reload()
 			std::string("~") + _("Saved web pages"));
 	}
 
-	FileUrlReader ur(file);
-	const auto error_message = ur.reload();
-	if (error_message.has_value()) {
-		LOG(Level::DEBUG, "Reloading failed: %s", error_message.value().message);
-		// Ignore errors for now: https://github.com/newsboat/newsboat/issues/1273
-	}
-
-	std::vector<std::string>& file_urls(ur.get_urls());
-	for (const auto& url : file_urls) {
-		if (utils::is_query_url(url)) {
-			urls.push_back(url);
-			std::vector<std::string>& file_tags(ur.get_tags(url));
-			tags[url] = ur.get_tags(url);
-			for (const auto& tag : file_tags) {
-				alltags.insert(tag);
-			}
-		}
-	}
+	load_query_urls_from_file(file);
 
 	std::vector<TaggedFeedUrl> feedurls = api->get_subscribed_urls();
 	for (const auto& url : feedurls) {
@@ -81,14 +62,13 @@ nonstd::optional<utils::ReadTextFileError> InoreaderUrlReader::reload()
 		tags[url.first] = url.second;
 		for (const auto& tag : url.second) {
 			LOG(Level::DEBUG, "%s: added tag %s", url.first, tag);
-			alltags.insert(tag);
 		}
 	}
 
 	return {};
 }
 
-std::string InoreaderUrlReader::get_source()
+std::string InoreaderUrlReader::get_source() const
 {
 	return "inoreader";
 }
