@@ -6,6 +6,9 @@
 #include <vector>
 
 #include "config.h"
+#include "curldatareceiver.h"
+#include "curlhandle.h"
+#include "logger.h"
 #include "strprintf.h"
 #include "utils.h"
 
@@ -25,15 +28,9 @@
 
 namespace newsboat {
 
-OldReaderApi::OldReaderApi(ConfigContainer* c)
+OldReaderApi::OldReaderApi(ConfigContainer& c)
 	: RemoteApi(c)
 {
-	// TODO
-}
-
-OldReaderApi::~OldReaderApi()
-{
-	// TODO
 }
 
 bool OldReaderApi::authenticate()
@@ -43,27 +40,19 @@ bool OldReaderApi::authenticate()
 	return auth != "";
 }
 
-static size_t my_write_data(void* buffer, size_t size, size_t nmemb,
-	void* userp)
-{
-	std::string* pbuf = static_cast<std::string*>(userp);
-	pbuf->append(static_cast<const char*>(buffer), size * nmemb);
-	return size * nmemb;
-}
-
 std::string OldReaderApi::retrieve_auth()
 {
-	CURL* handle = curl_easy_init();
+	CurlHandle handle;
 	Credentials cred = get_credentials("oldreader", "The Old Reader");
 	if (cred.user.empty() || cred.pass.empty()) {
 		return "";
 	}
 
-	char* username = curl_easy_escape(handle, cred.user.c_str(), 0);
-	char* password = curl_easy_escape(handle, cred.pass.c_str(), 0);
+	char* username = curl_easy_escape(handle.ptr(), cred.user.c_str(), 0);
+	char* password = curl_easy_escape(handle.ptr(), cred.pass.c_str(), 0);
 
 	std::string postcontent = strprintf::fmt(
-			"service=reader&Email=%s&Passwd=%s&source=%s%2F%s&accountType="
+			"service=reader&Email=%s&Passwd=%s&source=%s%%2F%s&accountType="
 			"HOSTED_OR_GOOGLE&continue=http://www.google.com/",
 			username,
 			password,
@@ -73,16 +62,15 @@ std::string OldReaderApi::retrieve_auth()
 	curl_free(username);
 	curl_free(password);
 
-	std::string result;
-
 	utils::set_common_curl_options(handle, cfg);
-	curl_easy_setopt(handle, CURLOPT_WRITEFUNCTION, my_write_data);
-	curl_easy_setopt(handle, CURLOPT_WRITEDATA, &result);
-	curl_easy_setopt(handle, CURLOPT_POSTFIELDS, postcontent.c_str());
-	curl_easy_setopt(handle, CURLOPT_URL, OLDREADER_LOGIN);
-	curl_easy_perform(handle);
-	curl_easy_cleanup(handle);
+	curl_easy_setopt(handle.ptr(), CURLOPT_POSTFIELDS, postcontent.c_str());
+	curl_easy_setopt(handle.ptr(), CURLOPT_URL, OLDREADER_LOGIN);
 
+	auto curlDataReceiver = CurlDataReceiver::register_data_handler(handle);
+
+	curl_easy_perform(handle.ptr());
+
+	const std::string result = curlDataReceiver->get_data();
 	std::vector<std::string> lines = utils::tokenize(result);
 	for (const auto& line : lines) {
 		LOG(Level::DEBUG,
@@ -102,19 +90,19 @@ std::vector<TaggedFeedUrl> OldReaderApi::get_subscribed_urls()
 	std::vector<TaggedFeedUrl> urls;
 	curl_slist* custom_headers{};
 
-	CURL* handle = curl_easy_init();
-	std::string result;
+	CurlHandle handle;
 	add_custom_headers(&custom_headers);
-	curl_easy_setopt(handle, CURLOPT_HTTPHEADER, custom_headers);
+	curl_easy_setopt(handle.ptr(), CURLOPT_HTTPHEADER, custom_headers);
 
 	utils::set_common_curl_options(handle, cfg);
-	curl_easy_setopt(handle, CURLOPT_WRITEFUNCTION, my_write_data);
-	curl_easy_setopt(handle, CURLOPT_WRITEDATA, &result);
-	curl_easy_setopt(handle, CURLOPT_URL, OLDREADER_SUBSCRIPTION_LIST);
-	curl_easy_perform(handle);
-	curl_easy_cleanup(handle);
+	curl_easy_setopt(handle.ptr(), CURLOPT_URL, OLDREADER_SUBSCRIPTION_LIST);
+
+	auto curlDataReceiver = CurlDataReceiver::register_data_handler(handle);
+
+	curl_easy_perform(handle.ptr());
 	curl_slist_free_all(custom_headers);
 
+	const std::string result = curlDataReceiver->get_data();
 	LOG(Level::DEBUG,
 		"OldReaderApi::get_subscribed_urls: document = %s",
 		result);
@@ -143,9 +131,20 @@ std::vector<TaggedFeedUrl> OldReaderApi::get_subscribed_urls()
 
 		json_object_object_get_ex(sub, "id", &node);
 		const char* id = json_object_get_string(node);
+		if (id == nullptr) {
+			LOG(Level::WARN, "Skipping a subscription without an id");
+			continue;
+		}
 
 		json_object_object_get_ex(sub, "title", &node);
-		const char* title = json_object_get_string(node);
+		const char* title_ptr = json_object_get_string(node);
+		std::string title;
+		if (title_ptr != nullptr) {
+			title = title_ptr;
+		} else {
+			LOG(Level::WARN, "Subscription has no title, so let's call it \"%i\"", i);
+			title = std::to_string(i);
+		}
 
 		// Ignore URLs where ID start with given prefix - those never
 		// load, always returning 404 and annoying people
@@ -168,16 +167,18 @@ std::vector<TaggedFeedUrl> OldReaderApi::get_subscribed_urls()
 				json_object* label_node{};
 				json_object_object_get_ex(
 					cat, "label", &label_node);
-				const char* label =
-					json_object_get_string(label_node);
+				const char* label = json_object_get_string(label_node);
+				if (label == nullptr) {
+					LOG(Level::WARN, "Skipping subscription's label whose name is a null value");
+					continue;
+				}
 				tags.push_back(std::string(label));
 			}
 
 			auto url = strprintf::fmt("%s%s?n=%u",
 					OLDREADER_FEED_PREFIX,
 					id,
-					cfg->get_configvalue_as_int(
-						"oldreader-min-items"));
+					cfg.get_configvalue_as_int("oldreader-min-items"));
 			urls.push_back(TaggedFeedUrl(url, tags));
 		}
 	}
@@ -268,20 +269,20 @@ bool OldReaderApi::mark_article_read_with_token(const std::string& guid,
 
 std::string OldReaderApi::get_new_token()
 {
-	CURL* handle = curl_easy_init();
-	std::string result;
+	CurlHandle handle;
 	curl_slist* custom_headers{};
 
 	utils::set_common_curl_options(handle, cfg);
 	add_custom_headers(&custom_headers);
-	curl_easy_setopt(handle, CURLOPT_HTTPHEADER, custom_headers);
-	curl_easy_setopt(handle, CURLOPT_WRITEFUNCTION, my_write_data);
-	curl_easy_setopt(handle, CURLOPT_WRITEDATA, &result);
-	curl_easy_setopt(handle, CURLOPT_URL, OLDREADER_API_TOKEN_URL);
-	curl_easy_perform(handle);
-	curl_easy_cleanup(handle);
+	curl_easy_setopt(handle.ptr(), CURLOPT_HTTPHEADER, custom_headers);
+	curl_easy_setopt(handle.ptr(), CURLOPT_URL, OLDREADER_API_TOKEN_URL);
+
+	auto curlDataReceiver = CurlDataReceiver::register_data_handler(handle);
+
+	curl_easy_perform(handle.ptr());
 	curl_slist_free_all(custom_headers);
 
+	const std::string result = curlDataReceiver->get_data();
 	LOG(Level::DEBUG, "OldReaderApi::get_new_token: token = %s", result);
 
 	return result;
@@ -291,28 +292,20 @@ bool OldReaderApi::update_article_flags(const std::string& oldflags,
 	const std::string& newflags,
 	const std::string& guid)
 {
-	std::string star_flag = cfg->get_configvalue("oldreader-flag-star");
-	std::string share_flag = cfg->get_configvalue("oldreader-flag-share");
+	std::string star_flag = cfg.get_configvalue("oldreader-flag-star");
+	std::string share_flag = cfg.get_configvalue("oldreader-flag-share");
 	bool success = true;
 
 	if (star_flag.length() > 0) {
-		if (strchr(oldflags.c_str(), star_flag[0]) == nullptr &&
-			strchr(newflags.c_str(), star_flag[0]) != nullptr) {
-			success = star_article(guid, true);
-		} else if (strchr(oldflags.c_str(), star_flag[0]) != nullptr &&
-			strchr(newflags.c_str(), star_flag[0]) == nullptr) {
-			success = star_article(guid, false);
-		}
+		update_flag(oldflags, newflags, star_flag[0], [&](bool added) {
+			success = star_article(guid, added);
+		});
 	}
 
 	if (share_flag.length() > 0) {
-		if (strchr(oldflags.c_str(), share_flag[0]) == nullptr &&
-			strchr(newflags.c_str(), share_flag[0]) != nullptr) {
-			success = share_article(guid, true);
-		} else if (strchr(oldflags.c_str(), share_flag[0]) != nullptr &&
-			strchr(newflags.c_str(), share_flag[0]) == nullptr) {
-			success = share_article(guid, false);
-		}
+		update_flag(oldflags, newflags, share_flag[0], [&](bool added) {
+			success = share_article(guid, added);
+		});
 	}
 
 	return success;
@@ -367,21 +360,21 @@ bool OldReaderApi::share_article(const std::string& guid, bool share)
 std::string OldReaderApi::post_content(const std::string& url,
 	const std::string& postdata)
 {
-	std::string result;
 	curl_slist* custom_headers{};
 
-	CURL* handle = curl_easy_init();
+	CurlHandle handle;
 	utils::set_common_curl_options(handle, cfg);
 	add_custom_headers(&custom_headers);
-	curl_easy_setopt(handle, CURLOPT_HTTPHEADER, custom_headers);
-	curl_easy_setopt(handle, CURLOPT_WRITEFUNCTION, my_write_data);
-	curl_easy_setopt(handle, CURLOPT_WRITEDATA, &result);
-	curl_easy_setopt(handle, CURLOPT_POSTFIELDS, postdata.c_str());
-	curl_easy_setopt(handle, CURLOPT_URL, url.c_str());
-	curl_easy_perform(handle);
-	curl_easy_cleanup(handle);
+	curl_easy_setopt(handle.ptr(), CURLOPT_HTTPHEADER, custom_headers);
+	curl_easy_setopt(handle.ptr(), CURLOPT_POSTFIELDS, postdata.c_str());
+	curl_easy_setopt(handle.ptr(), CURLOPT_URL, url.c_str());
+
+	auto curlDataReceiver = CurlDataReceiver::register_data_handler(handle);
+
+	curl_easy_perform(handle.ptr());
 	curl_slist_free_all(custom_headers);
 
+	const std::string result = curlDataReceiver->get_data();
 	LOG(Level::DEBUG,
 		"OldReaderApi::post_content: url = %s postdata = %s result = "
 		"%s",
