@@ -148,14 +148,28 @@ void rec_find_rss_outlines(
 				auto& urls = urlcfg.get_urls();
 				if (std::find(urls.begin(), urls.end(), quoted_url) == urls.end()) {
 					LOG(Level::DEBUG, "opml::import: added url = %s", quoted_url);
-					urls.push_back(quoted_url);
+					std::vector<std::string> tags;
+
+					char* text_p = (char*)xmlGetProp(node, (const xmlChar*)"text");
+					if (!text_p) {
+						text_p = (char*)xmlGetProp(node, (const xmlChar*)"title");
+					}
+					if (text_p) {
+						if (text_p[0] != '\0') {
+							tags.push_back(std::string{"~"} + text_p);
+						}
+						xmlFree(text_p);
+					}
+
 					if (tag.length() > 0) {
 						LOG(Level::DEBUG,
 							"opml::import: appending tag %s to url %s",
 							tag,
 							quoted_url);
-						urlcfg.get_tags(quoted_url).push_back(tag);
+						tags.push_back(tag);
 					}
+
+					urlcfg.add_url(quoted_url, tags);
 				} else {
 					LOG(Level::DEBUG,
 						"opml::import: url = %s is already in list",
@@ -201,16 +215,16 @@ void rec_find_rss_outlines(
 	}
 }
 
-nonstd::optional<std::string> opml::import(
-	const std::string& filename,
+std::optional<std::string> opml::import(
+	const Filepath& filename,
 	FileUrlReader& urlcfg)
 {
-	xmlDoc* doc = xmlReadFile(filename.c_str(), nullptr, 0);
+	xmlDoc* doc = xmlReadFile(filename.to_locale_string().c_str(), nullptr, 0);
 	if (doc == nullptr) {
 		return strprintf::fmt(_("Error: failed to parse OPML file \"%s\""), filename);
 	}
 
-	nonstd::optional<std::string> error_message;
+	std::optional<std::string> error_message;
 
 	xmlNode* root = xmlDocGetRootElement(doc);
 	for (xmlNode* node = root->children; node != nullptr;
