@@ -22,7 +22,7 @@
 
 namespace newsboat {
 
-Reloader::Reloader(Controller* c, Cache* cc, ConfigContainer& cfg)
+Reloader::Reloader(Controller& c, Cache& cc, ConfigContainer& cfg)
 	: ctrl(c)
 	, rsscache(cc)
 	, cfg(cfg)
@@ -35,7 +35,7 @@ void Reloader::spawn_reloadthread()
 	t.detach();
 }
 
-void Reloader::start_reload_all_thread(const std::vector<int>& indexes)
+void Reloader::start_reload_all_thread(const std::vector<unsigned int>& indexes)
 {
 	LOG(Level::INFO, "starting reload all thread");
 	std::thread t([=]() {
@@ -71,7 +71,7 @@ void Reloader::reload(unsigned int pos,
 {
 	ScopeMeasure sm("Reloader::reload");
 	LOG(Level::DEBUG, "Reloader::reload: pos = %u", pos);
-	std::shared_ptr<RssFeed> oldfeed = ctrl->get_feedcontainer()->get_feed(pos);
+	std::shared_ptr<RssFeed> oldfeed = ctrl.get_feedcontainer()->get_feed(pos);
 	if (oldfeed) {
 		LOG(Level::INFO, "Reloader::reload: starting reload of %s", oldfeed->rssurl());
 
@@ -88,7 +88,7 @@ void Reloader::reload(unsigned int pos,
 			const std::string progress = show_progress ?
 				strprintf::fmt("(%u/%u) ", ++reload_progress, reload_progress_max) :
 				"";
-			message_lifetime = ctrl->get_view()->get_statusline().show_message_until_finished(
+			message_lifetime = ctrl.get_view()->get_statusline().show_message_until_finished(
 					strprintf::fmt(_("%sLoading %s..."),
 						progress,
 						utils::censor_url(oldfeed->rssurl())));
@@ -102,22 +102,22 @@ void Reloader::reload(unsigned int pos,
 			message_lifetime.reset();
 			oldfeed->set_status(DlStatus::DURING_DOWNLOAD);
 
-			RssIgnores* ign = ignore_dl ? ctrl->get_ignores() : nullptr;
+			RssIgnores* ign = ignore_dl ? ctrl.get_ignores() : nullptr;
 
 			LOG(Level::INFO, "Reloader::reload: retrieving feed");
 			sm.stopover("start retrieving");
-			FeedRetriever feed_retriever(cfg, *rsscache, easyhandle, ign, ctrl->get_api());
+			FeedRetriever feed_retriever(cfg, rsscache, easyhandle, ign, ctrl.get_api());
 			const rsspp::Feed feed = feed_retriever.retrieve(oldfeed->rssurl());
 
 			LOG(Level::INFO, "Reloader::reload: parsing feed");
 			sm.stopover("start parsing");
-			RssParser parser(oldfeed->rssurl(), *rsscache, cfg, ign);
+			RssParser parser(oldfeed->rssurl(), rsscache, cfg, ign);
 
 			std::shared_ptr<RssFeed> newfeed = parser.parse(feed);
 			sm.stopover("start replacing feed");
 			if (newfeed != nullptr) {
-				ctrl->replace_feed(
-					oldfeed, newfeed, pos, unattended);
+				ctrl.replace_feed(
+					*oldfeed, *newfeed, pos, unattended);
 				if (newfeed->total_item_count() == 0) {
 					LOG(Level::DEBUG,
 						"Reloader::reload: feed is empty");
@@ -134,19 +134,22 @@ void Reloader::reload(unsigned int pos,
 					_("Error while retrieving %s: %s"),
 					utils::censor_url(oldfeed->rssurl()),
 					emsg);
-		} catch (rsspp::Exception& e) {
+		} catch (const rsspp::Exception& e) {
 			errmsg = strprintf::fmt(
 					_("Error while retrieving %s: %s"),
 					utils::censor_url(oldfeed->rssurl()),
 					e.what());
+		} catch (const rsspp::NotModifiedException&) {
+			// Nothing to be done, feed was not chaned since last retrieve
+			oldfeed->set_status(DlStatus::SUCCESS);
 		}
 		if (!errmsg.empty()) {
 			oldfeed->set_status(DlStatus::DL_ERROR);
-			ctrl->get_view()->get_statusline().show_error(errmsg);
+			ctrl.get_view()->get_statusline().show_error(errmsg);
 			LOG(Level::USERERROR, "%s", errmsg);
 		}
 	} else {
-		ctrl->get_view()->get_statusline().show_error(_("Error: invalid feed!"));
+		ctrl.get_view()->get_statusline().show_error(_("Error: invalid feed!"));
 	}
 }
 
@@ -194,23 +197,25 @@ void Reloader::reload_all(bool unattended)
 	ScopeMeasure sm("Reloader::reload_all");
 
 	const auto unread_feeds =
-		ctrl->get_feedcontainer()->unread_feed_count();
+		ctrl.get_feedcontainer()->unread_feed_count();
 	const auto unread_articles =
-		ctrl->get_feedcontainer()->unread_item_count();
+		ctrl.get_feedcontainer()->unread_item_count();
 
-	ctrl->get_feedcontainer()->reset_feeds_status();
-	const auto num_feeds = ctrl->get_feedcontainer()->feeds_size();
+	ctrl.get_feedcontainer()->reset_feeds_status();
+	const auto num_feeds = ctrl.get_feedcontainer()->feeds_size();
 
-	partition_reload_to_threads([=](unsigned int start, unsigned int end) {
-		reload_range(start, end, unattended);
-	}, num_feeds);
+	std::vector<unsigned int> v;
+	for (unsigned int i = 0; i < num_feeds; ++i) {
+		v.push_back(i);
+	}
+	reload_indexes_impl(v, unattended);
 
 	// refresh query feeds (update and sort)
 	LOG(Level::DEBUG, "Reloader::reload_all: refresh query feeds");
-	for (const auto& feed : ctrl->get_feedcontainer()->get_all_feeds()) {
+	for (const auto& feed : ctrl.get_feedcontainer()->get_all_feeds()) {
 		if (feed->is_query_feed()) {
 			try {
-				ctrl->get_view()->prepare_query_feed(feed);
+				ctrl.get_view()->prepare_query_feed(feed);
 				feed->set_status(DlStatus::SUCCESS);
 			} catch (const MatcherException& /* e */) {
 				feed->set_status(DlStatus::DL_ERROR);
@@ -218,40 +223,15 @@ void Reloader::reload_all(bool unattended)
 		}
 	}
 
-	ctrl->get_feedcontainer()->sort_feeds(cfg.get_feed_sort_strategy());
-	ctrl->update_feedlist();
-	ctrl->get_view()->force_redraw();
+	ctrl.get_feedcontainer()->sort_feeds(cfg.get_feed_sort_strategy());
+	ctrl.update_feedlist();
+	ctrl.get_view()->force_redraw();
 
 	notify_reload_finished(unread_feeds, unread_articles);
 }
 
-void Reloader::reload_indexes(const std::vector<int>& indexes, bool unattended)
+void Reloader::reload_indexes_impl(std::vector<unsigned int> indexes, bool unattended)
 {
-	ScopeMeasure m1("Reloader::reload_indexes");
-	const auto unread_feeds =
-		ctrl->get_feedcontainer()->unread_feed_count();
-	const auto unread_articles =
-		ctrl->get_feedcontainer()->unread_item_count();
-
-	partition_reload_to_threads([&](unsigned int start, unsigned int end) {
-		for (auto i = start; i <= end; ++i) {
-			CurlHandle easyhandle;
-			reload(indexes[i], easyhandle, true, unattended);
-		}
-	}, indexes.size());
-
-	notify_reload_finished(unread_feeds, unread_articles);
-}
-
-void Reloader::reload_range(unsigned int start,
-	unsigned int end,
-	bool unattended)
-{
-	std::vector<unsigned int> v;
-	for (unsigned int i = start; i <= end; ++i) {
-		v.push_back(i);
-	}
-
 	auto extract = [](std::string& s, const std::string& url) {
 		size_t p = url.find("//");
 		p = (p == std::string::npos) ? 0 : p + 2;
@@ -260,9 +240,13 @@ void Reloader::reload_range(unsigned int start,
 		s = suff.substr(0, p);
 	};
 
-	const auto feeds = ctrl->get_feedcontainer()->get_all_feeds();
+	const auto feeds = ctrl.get_feedcontainer()->get_all_feeds();
 
-	std::sort(v.begin(), v.end(), [&](unsigned int a, unsigned int b) {
+	// Sort the feeds based on domain, so feeds on the same domain
+	// can share the curl handle.
+	//
+	// See commit: 115cf667485929bbb698ba8051dec7ff6a73739c
+	std::sort(indexes.begin(), indexes.end(), [&](unsigned int a, unsigned int b) {
 		std::string domain1, domain2;
 		extract(domain1, feeds[a]->rssurl());
 		extract(domain2, feeds[b]->rssurl());
@@ -271,14 +255,38 @@ void Reloader::reload_range(unsigned int start,
 		return domain1 < domain2;
 	});
 
-	CurlHandle easyhandle;
+	partition_reload_to_threads([&](unsigned int start, unsigned int end) {
+		CurlHandle easyhandle;
+		for (auto i = start; i <= end; ++i) {
+			unsigned int feed_index = indexes[i];
+			LOG(Level::DEBUG,
+				"Reloader::reload_indexes_impl: reloading feed #%u",
+				feed_index);
+			reload(feed_index, easyhandle, true, unattended);
 
-	for (const auto& i : v) {
-		LOG(Level::DEBUG,
-			"Reloader::reload_range: reloading feed #%u",
-			i);
-		reload(i, easyhandle, true, unattended);
-	}
+			// Reset any options set on the handle before next reload
+			curl_easy_reset(easyhandle.ptr());
+
+			// Restore cookiejar config to make sure option is active during curl_easy_cleanup()
+			const auto cookie_cache = cfg.get_configvalue("cookie-cache");
+			if (cookie_cache != "") {
+				curl_easy_setopt(easyhandle.ptr(), CURLOPT_COOKIEJAR, cookie_cache.c_str());
+			}
+		}
+	}, indexes.size());
+}
+
+void Reloader::reload_indexes(const std::vector<unsigned int>& indexes, bool unattended)
+{
+	ScopeMeasure m1("Reloader::reload_indexes");
+	const auto unread_feeds =
+		ctrl.get_feedcontainer()->unread_feed_count();
+	const auto unread_articles =
+		ctrl.get_feedcontainer()->unread_item_count();
+
+	reload_indexes_impl(indexes, unattended);
+
+	notify_reload_finished(unread_feeds, unread_articles);
 }
 
 void Reloader::notify(const std::string& msg)
@@ -297,12 +305,12 @@ void Reloader::notify(const std::string& msg)
 		LOG(Level::DEBUG, "reloader:notify: notifying beep");
 		::beep();
 	}
-	if (cfg.get_configvalue("notify-program").length() > 0) {
-		std::string prog = cfg.get_configvalue("notify-program");
+	const auto notify_program = cfg.get_configvalue_as_filepath("notify-program");
+	if (notify_program != Filepath{}) {
 		LOG(Level::DEBUG,
 			"reloader:notify: notifying external program `%s'",
-			prog);
-		utils::run_command(prog, msg);
+			notify_program);
+		utils::run_command(notify_program.to_locale_string(), msg);
 	}
 }
 
@@ -310,9 +318,9 @@ void Reloader::notify_reload_finished(unsigned int unread_feeds_before,
 	unsigned int unread_articles_before)
 {
 	const auto unread_feeds =
-		ctrl->get_feedcontainer()->unread_feed_count();
+		ctrl.get_feedcontainer()->unread_feed_count();
 	const auto unread_articles =
-		ctrl->get_feedcontainer()->unread_item_count();
+		ctrl.get_feedcontainer()->unread_item_count();
 	const bool notify_always = cfg.get_configvalue_as_bool("notify-always");
 
 	if (notify_always || unread_feeds > unread_feeds_before ||
