@@ -11,6 +11,7 @@
 #include <langinfo.h>
 #include <libxml/uri.h>
 #include <mutex>
+#include <ncurses.h>
 #include <pwd.h>
 #include <sstream>
 #include <stfl.h>
@@ -64,7 +65,7 @@ std::vector<std::string> utils::tokenize_quoted(const std::string& str,
 	return result;
 }
 
-nonstd::optional<std::string> utils::extract_token_quoted(std::string& str,
+std::optional<std::string> utils::extract_token_quoted(std::string& str,
 	std::string delimiters)
 {
 	rust::String remaining = str;
@@ -343,15 +344,19 @@ std::string utils::run_program(const char* argv[], const std::string& input)
 	return std::string(utils::bridged::run_program(rs_argv, input));
 }
 
-std::string utils::resolve_tilde(const std::string& str)
+Filepath utils::resolve_tilde(const Filepath& path)
 {
-	return std::string(utils::bridged::resolve_tilde(str));
+	auto output = filepath::bridged::create_empty();
+	utils::bridged::resolve_tilde(path, *output);
+	return output;
 }
 
-std::string utils::resolve_relative(const std::string& reference,
-	const std::string& fname)
+Filepath utils::resolve_relative(const Filepath& reference,
+	const Filepath& fname)
 {
-	return std::string(utils::bridged::resolve_relative(reference, fname));
+	auto output = filepath::bridged::create_empty();
+	utils::bridged::resolve_relative(reference, fname, *output);
+	return output;
 }
 
 std::string utils::replace_all(std::string str,
@@ -362,7 +367,7 @@ std::string utils::replace_all(std::string str,
 }
 
 std::string utils::replace_all(const std::string& str,
-	const std::vector<std::pair<std::string, std::string>> from_to_pairs)
+	const std::vector<std::pair<std::string, std::string>>& from_to_pairs)
 {
 	std::size_t cur_index = 0;
 	std::string output;
@@ -593,15 +598,14 @@ void utils::set_common_curl_options(CurlHandle& handle, ConfigContainer& cfg)
 		cfg.get_configvalue_as_int("download-timeout");
 	curl_easy_setopt(handle.ptr(), CURLOPT_TIMEOUT, dl_timeout);
 
-	const std::string cookie_cache =
-		cfg.get_configvalue("cookie-cache");
-	if (cookie_cache != "") {
+	const Filepath cookie_cache = cfg.get_configvalue_as_filepath("cookie-cache");
+	if (cookie_cache != Filepath{}) {
 		curl_easy_setopt(handle.ptr(),
 			CURLOPT_COOKIEFILE,
-			cookie_cache.c_str());
+			cookie_cache.to_locale_string().c_str());
 		curl_easy_setopt(handle.ptr(),
 			CURLOPT_COOKIEJAR,
-			cookie_cache.c_str());
+			cookie_cache.to_locale_string().c_str());
 	}
 
 	curl_easy_setopt(handle.ptr(),
@@ -643,7 +647,7 @@ std::string utils::get_basename(const std::string& url)
 	return std::string(utils::bridged::get_basename(url));
 }
 
-curl_proxytype utils::get_proxy_type(const std::string& type)
+long int utils::get_proxy_type(const std::string& type)
 {
 	if (type == "http") {
 		return CURLPROXY_HTTP;
@@ -695,7 +699,7 @@ std::wstring utils::clean_nonprintable_characters(std::wstring text)
 
 /* Like mkdir(), but creates ancestors (parent directories) if they don't
  * exist. */
-int utils::mkdir_parents(const std::string& p, mode_t mode)
+int utils::mkdir_parents(const Filepath& p, mode_t mode)
 {
 	return utils::bridged::mkdir_parents(p, static_cast<std::uint32_t>(mode));
 }
@@ -705,7 +709,7 @@ std::string utils::make_title(const std::string& const_url)
 	return std::string(utils::bridged::make_title(const_url));
 }
 
-nonstd::optional<std::uint8_t> utils::run_interactively(
+std::optional<std::uint8_t> utils::run_interactively(
 	const std::string& command,
 	const std::string& caller)
 {
@@ -714,10 +718,10 @@ nonstd::optional<std::uint8_t> utils::run_interactively(
 		return exit_code;
 	}
 
-	return nonstd::nullopt;
+	return std::nullopt;
 }
 
-nonstd::optional<std::uint8_t> utils::run_non_interactively(
+std::optional<std::uint8_t> utils::run_non_interactively(
 	const std::string& command,
 	const std::string& caller)
 {
@@ -726,21 +730,26 @@ nonstd::optional<std::uint8_t> utils::run_non_interactively(
 		return exit_code;
 	}
 
-	return nonstd::nullopt;
+	return std::nullopt;
 }
 
-std::string utils::getcwd()
+Filepath utils::getcwd()
 {
-	return std::string(utils::bridged::getcwd());
+	auto path = filepath::bridged::create_empty();
+	utils::bridged::getcwd(*path);
+	return path;
 }
 
 nonstd::expected<std::vector<std::string>, utils::ReadTextFileError> utils::read_text_file(
-	const std::string& filename)
+	const Filepath& filename)
 {
 	rust::Vec<rust::String> c;
 	std::uint64_t error_line_number{};
 	rust::String error_reason;
-	const bool result = bridged::read_text_file(filename, c, error_line_number,
+	const bool result = bridged::read_text_file(
+			filename,
+			c,
+			error_line_number,
 			error_reason);
 
 	if (result) {
@@ -778,7 +787,7 @@ bool utils::is_valid_podcast_type(const std::string& mimetype)
 	return utils::bridged::is_valid_podcast_type(mimetype);
 }
 
-nonstd::optional<LinkType> utils::podcast_mime_to_link_type(
+std::optional<LinkType> utils::podcast_mime_to_link_type(
 	const std::string& mimetype)
 {
 	std::int64_t result = 0;
@@ -786,7 +795,7 @@ nonstd::optional<LinkType> utils::podcast_mime_to_link_type(
 		return static_cast<LinkType>(result);
 	}
 
-	return nonstd::nullopt;
+	return std::nullopt;
 }
 
 std::string utils::string_from_utf8_lossy(const std::vector<std::uint8_t>& text)
@@ -796,6 +805,17 @@ std::string utils::string_from_utf8_lossy(const std::vector<std::uint8_t>& text)
 	return std::string(result);
 }
 
+void utils::parse_rss_author_email(const std::vector<std::uint8_t>& text,
+	std::string& name, std::string& email)
+{
+	auto input = rust::Slice<std::uint8_t const>(text.data(), text.size());
+	rust::String name_rs;
+	rust::String email_rs;
+	utils::bridged::parse_rss_author_email(input, name_rs, email_rs);
+	name = std::string(name_rs);
+	email = std::string(email_rs);
+}
+
 /*
  * See
  * http://curl.haxx.se/libcurl/c/libcurl-tutorial.html#Multi-threading
@@ -854,9 +874,11 @@ void utils::initialize_ssl_implementation(void)
 #endif
 }
 
-std::string utils::get_default_browser()
+Filepath utils::get_default_browser()
 {
-	return std::string(utils::bridged::get_default_browser());
+	auto path = filepath::bridged::create_empty();
+	utils::bridged::get_default_browser(*path);
+	return path;
 }
 
 std::string utils::md5hash(const std::string& input)
@@ -889,4 +911,14 @@ std::string utils::mt_strf_localtime(const std::string& format, time_t t)
 	return std::string(buffer, written);
 }
 
+void utils::wait_for_keypress()
+{
+	initscr();
+	cbreak(); // Disable line buffering
+	raw(); // Make sure we return from getch on Ctrl+C instead of calling the signal handler
+	timeout(-1); // Make getch wait indefinitely
+	getch();
+	endwin(); // Restore terminal settings
+}
+
 } // namespace newsboat
