@@ -17,17 +17,17 @@ using namespace newsboat;
 TEST_CASE("items in search result can be marked read", "[Cache]")
 {
 	ConfigContainer cfg;
-	Cache rsscache(":memory:", &cfg);
+	auto rsscache = Cache::in_memory(cfg);
 	const std::string uri = "file://data/rss.xml";
 	CurlHandle easyHandle;
-	FeedRetriever feed_retriever(cfg, rsscache, easyHandle);
-	RssParser parser(uri, rsscache, cfg, nullptr);
+	FeedRetriever feed_retriever(cfg, *rsscache, easyHandle);
+	RssParser parser(uri, *rsscache, cfg, nullptr);
 	auto feed = parser.parse(feed_retriever.retrieve(uri));
 	REQUIRE(feed->total_item_count() == 8);
-	rsscache.externalize_rssfeed(*feed, false);
+	rsscache->externalize_rssfeed(*feed, false);
 
 	RssIgnores ign;
-	auto search_items = rsscache.search_for_items("Botox", "", ign);
+	auto search_items = rsscache->search_for_items("Botox", "", ign);
 	REQUIRE(search_items.size() == 1);
 	auto item = search_items.front();
 	REQUIRE(item->unread());
@@ -35,7 +35,7 @@ TEST_CASE("items in search result can be marked read", "[Cache]")
 	item->set_unread(false);
 	search_items.clear();
 
-	search_items = rsscache.search_for_items("Botox", "", ign);
+	search_items = rsscache->search_for_items("Botox", "", ign);
 	REQUIRE(search_items.size() == 1);
 	auto updatedItem = search_items.front();
 	REQUIRE_FALSE(updatedItem->unread());
@@ -45,7 +45,7 @@ TEST_CASE("Cleaning old articles works", "[Cache]")
 {
 	test_helpers::TempFile dbfile;
 	auto cfg = std::make_unique<ConfigContainer>();
-	auto rsscache = std::make_unique<Cache>(dbfile.get_path(), cfg.get());
+	auto rsscache = std::make_unique<Cache>(dbfile.get_path(), *cfg);
 	const std::string uri = "file://data/rss.xml";
 	CurlHandle easyHandle;
 	FeedRetriever feed_retriever(*cfg, *rsscache, easyHandle);
@@ -76,7 +76,7 @@ TEST_CASE("Cleaning old articles works", "[Cache]")
 	 * are dating back to 2006. */
 	cfg = std::make_unique<ConfigContainer>();
 	cfg->set_configvalue("keep-articles-days", "42");
-	rsscache = std::make_unique<Cache>(dbfile.get_path(), cfg.get());
+	rsscache = std::make_unique<Cache>(dbfile.get_path(), *cfg);
 	feed = rsscache->internalize_rssfeed("file://data/rss.xml", nullptr);
 
 	/* The important part: old articles should be gone, new one remains. */
@@ -87,7 +87,7 @@ TEST_CASE("Last-Modified and ETag values are persisted to DB", "[Cache]")
 {
 	auto cfg = std::make_unique<ConfigContainer>();
 	test_helpers::TempFile dbfile;
-	auto rsscache = std::make_unique<Cache>(dbfile.get_path(), cfg.get());
+	auto rsscache = std::make_unique<Cache>(dbfile.get_path(), *cfg);
 	const auto feedurl = "file://data/rss.xml";
 	CurlHandle easyHandle;
 	FeedRetriever feed_retriever(*cfg, *rsscache, easyHandle);
@@ -105,7 +105,7 @@ TEST_CASE("Last-Modified and ETag values are persisted to DB", "[Cache]")
 				feedurl, last_modified, etag));
 
 		cfg = std::make_unique<ConfigContainer>();
-		rsscache = std::make_unique<Cache>(dbfile.get_path(), cfg.get());
+		rsscache = std::make_unique<Cache>(dbfile.get_path(), *cfg);
 
 		/* Scrambling the value to make sure the following call changes
 		 * it. */
@@ -138,16 +138,16 @@ TEST_CASE("Last-Modified and ETag values are also stored in DB if feed was not y
 	"[Cache]")
 {
 	ConfigContainer cfg;
-	Cache rsscache(":memory:", &cfg);
+	auto rsscache = Cache::in_memory(cfg);
 
 	const std::string feedurl = "http://example.com/feed.xml";
 	const time_t lastmodified = 42;
 	const std::string etag = "abc";
-	rsscache.update_lastmodified(feedurl, lastmodified, etag);
+	rsscache->update_lastmodified(feedurl, lastmodified, etag);
 
 	time_t output_lastmodified{};
 	std::string output_etag;
-	rsscache.fetch_lastmodified(feedurl, output_lastmodified, output_etag);
+	rsscache->fetch_lastmodified(feedurl, output_lastmodified, output_etag);
 
 	REQUIRE(output_lastmodified == lastmodified);
 	REQUIRE(output_etag == etag);
@@ -158,9 +158,9 @@ TEST_CASE("mark_all_read marks all items in the feed read", "[Cache]")
 	std::shared_ptr<RssFeed> feed, test_feed;
 
 	ConfigContainer cfg;
-	Cache rsscache(":memory:", &cfg);
+	auto rsscache = Cache::in_memory(cfg);
 
-	test_feed = std::make_shared<RssFeed>(&rsscache, "");
+	test_feed = std::make_shared<RssFeed>(rsscache.get(), "");
 	test_feed->set_title("Test feed");
 	auto test_feed_url = "http://example.com/atom.xml";
 	test_feed->set_link(test_feed_url);
@@ -175,22 +175,22 @@ TEST_CASE("mark_all_read marks all items in the feed read", "[Cache]")
 	 * externalize them (put into Cache). */
 	for (const auto& feed_data : feeds) {
 		CurlHandle easyHandle;
-		FeedRetriever feed_retriever(cfg, rsscache, easyHandle);
-		RssParser parser(feed_data.first, rsscache, cfg, nullptr);
+		FeedRetriever feed_retriever(cfg, *rsscache, easyHandle);
+		RssParser parser(feed_data.first, *rsscache, cfg, nullptr);
 		feed = parser.parse(feed_retriever.retrieve(feed_data.first));
 		REQUIRE(feed->total_item_count() == feed_data.second);
 
 		test_feed->add_item(feed->items()[0]);
 
-		rsscache.externalize_rssfeed(*feed, false);
+		rsscache->externalize_rssfeed(*feed, false);
 	}
 
 	SECTION("empty feedurl") {
 		INFO("All items should be marked as read.");
-		rsscache.mark_all_read();
+		rsscache->mark_all_read();
 
 		for (const auto& feed_data : feeds) {
-			feed = rsscache.internalize_rssfeed(
+			feed = rsscache->internalize_rssfeed(
 					feed_data.first, nullptr);
 			for (const auto& item : feed->items()) {
 				REQUIRE_FALSE(item->unread());
@@ -201,16 +201,16 @@ TEST_CASE("mark_all_read marks all items in the feed read", "[Cache]")
 	SECTION("non-empty feedurl") {
 		INFO("All items with particular feedurl should be marked as "
 			"read");
-		rsscache.mark_all_read(feeds[0].first);
+		rsscache->mark_all_read(feeds[0].first);
 
 		INFO("First feed should all be marked read");
-		feed = rsscache.internalize_rssfeed(feeds[0].first, nullptr);
+		feed = rsscache->internalize_rssfeed(feeds[0].first, nullptr);
 		for (const auto& item : feed->items()) {
 			REQUIRE_FALSE(item->unread());
 		}
 
 		INFO("Second feed should all be marked unread");
-		feed = rsscache.internalize_rssfeed(feeds[1].first, nullptr);
+		feed = rsscache->internalize_rssfeed(feeds[1].first, nullptr);
 		for (const auto& item : feed->items()) {
 			REQUIRE(item->unread());
 		}
@@ -219,8 +219,8 @@ TEST_CASE("mark_all_read marks all items in the feed read", "[Cache]")
 	SECTION("actual feed") {
 		INFO("All items that are in the specific feed should be marked "
 			"as read");
-		rsscache.externalize_rssfeed(*test_feed, false);
-		rsscache.mark_all_read(*test_feed);
+		rsscache->externalize_rssfeed(*test_feed, false);
+		rsscache->mark_all_read(*test_feed);
 
 		/* Since test_feed contains the first item of each feed, only
 		 * these two items should be marked read. */
@@ -235,14 +235,14 @@ TEST_CASE("mark_all_read marks all items in the feed read", "[Cache]")
 		};
 
 		{
-			feed = rsscache.internalize_rssfeed(
+			feed = rsscache->internalize_rssfeed(
 					test_feed_url, nullptr);
 			INFO("Test feed should all be marked read");
 			REQUIRE(unread_items_count(feed) == 0);
 		}
 
 		{
-			feed = rsscache.internalize_rssfeed(
+			feed = rsscache->internalize_rssfeed(
 					feeds[0].first, nullptr);
 			INFO("First feed should have just one item read");
 			REQUIRE(unread_items_count(feed) ==
@@ -250,7 +250,7 @@ TEST_CASE("mark_all_read marks all items in the feed read", "[Cache]")
 		}
 
 		{
-			feed = rsscache.internalize_rssfeed(
+			feed = rsscache->internalize_rssfeed(
 					feeds[1].first, nullptr);
 			INFO("Second feed should have just one item read");
 			REQUIRE(unread_items_count(feed) ==
@@ -272,7 +272,7 @@ TEST_CASE(
 
 	std::vector<std::shared_ptr<RssFeed>> feeds;
 	auto cfg = std::make_unique<ConfigContainer>();
-	auto rsscache = std::make_unique<Cache>(dbfile.get_path(), cfg.get());
+	auto rsscache = std::make_unique<Cache>(dbfile.get_path(), *cfg);
 	for (const auto& url : feedurls) {
 		CurlHandle easyHandle;
 		FeedRetriever feed_retriever(*cfg, *rsscache, easyHandle);
@@ -287,7 +287,7 @@ TEST_CASE(
 		rsscache->cleanup_cache(feeds);
 
 		cfg = std::make_unique<ConfigContainer>();
-		rsscache = std::make_unique<Cache>(dbfile.get_path(), cfg.get());
+		rsscache = std::make_unique<Cache>(dbfile.get_path(), *cfg);
 
 		for (const auto& url : feedurls) {
 			std::shared_ptr<RssFeed> feed =
@@ -306,7 +306,7 @@ TEST_CASE(
 			rsscache->cleanup_cache(feeds);
 
 			cfg = std::make_unique<ConfigContainer>();
-			rsscache = std::make_unique<Cache>(dbfile.get_path(), cfg.get());
+			rsscache = std::make_unique<Cache>(dbfile.get_path(), *cfg);
 
 			std::shared_ptr<RssFeed> feed =
 				rsscache->internalize_rssfeed(
@@ -327,7 +327,7 @@ TEST_CASE(
 			rsscache->cleanup_cache(feeds);
 
 			cfg = std::make_unique<ConfigContainer>();
-			rsscache = std::make_unique<Cache>(dbfile.get_path(), cfg.get());
+			rsscache = std::make_unique<Cache>(dbfile.get_path(), *cfg);
 
 			std::shared_ptr<RssFeed> feed =
 				rsscache->internalize_rssfeed(
@@ -347,7 +347,7 @@ TEST_CASE(
 			rsscache->cleanup_cache(feeds, always_clean);
 
 			cfg = std::make_unique<ConfigContainer>();
-			rsscache = std::make_unique<Cache>(dbfile.get_path(), cfg.get());
+			rsscache = std::make_unique<Cache>(dbfile.get_path(), *cfg);
 
 			std::shared_ptr<RssFeed> feed =
 				rsscache->internalize_rssfeed(
@@ -368,7 +368,7 @@ TEST_CASE(
 			rsscache->cleanup_cache(feeds, always_clean);
 
 			cfg = std::make_unique<ConfigContainer>();
-			rsscache = std::make_unique<Cache>(dbfile.get_path(), cfg.get());
+			rsscache = std::make_unique<Cache>(dbfile.get_path(), *cfg);
 
 			std::shared_ptr<RssFeed> feed =
 				rsscache->internalize_rssfeed(
@@ -381,20 +381,20 @@ TEST_CASE(
 TEST_CASE("fetch_descriptions fills out feed item's descriptions", "[Cache]")
 {
 	ConfigContainer cfg;
-	Cache rsscache(":memory:", &cfg);
+	auto rsscache = Cache::in_memory(cfg);
 	const auto feedurl = "file://data/rss.xml";
 	CurlHandle easyHandle;
-	FeedRetriever feed_retriever(cfg, rsscache, easyHandle);
-	RssParser parser(feedurl, rsscache, cfg, nullptr);
+	FeedRetriever feed_retriever(cfg, *rsscache, easyHandle);
+	RssParser parser(feedurl, *rsscache, cfg, nullptr);
 	auto feed = parser.parse(feed_retriever.retrieve(feedurl));
 
-	rsscache.externalize_rssfeed(*feed, false);
+	rsscache->externalize_rssfeed(*feed, false);
 
 	for (auto& item : feed->items()) {
 		item->set_description("your test failed!", "text/plain");
 	}
 
-	REQUIRE_NOTHROW(rsscache.fetch_descriptions(feed.get()));
+	REQUIRE_NOTHROW(rsscache->fetch_descriptions(feed.get()));
 
 	for (auto& item : feed->items()) {
 		REQUIRE(item->description().text != "your test failed!");
@@ -406,7 +406,7 @@ TEST_CASE("get_read_item_guids returns GUIDs of items that are marked read",
 {
 	test_helpers::TempFile dbfile;
 	ConfigContainer cfg;
-	auto rsscache = std::make_unique<Cache>(dbfile.get_path(), &cfg);
+	auto rsscache = std::make_unique<Cache>(dbfile.get_path(), cfg);
 
 	// We'll keep our own count of which GUIDs are unread
 	std::unordered_set<std::string> read_guids;
@@ -458,7 +458,7 @@ TEST_CASE("get_read_item_guids returns GUIDs of items that are marked read",
 
 	// Lastly, let's make sure the info is indeed retrieved from the
 	// database and isn't just stored in the Cache object
-	rsscache = std::make_unique<Cache>(dbfile.get_path(), &cfg);
+	rsscache = std::make_unique<Cache>(dbfile.get_path(), cfg);
 	INFO("Testing on two feeds with new `Cache` object");
 	check(rsscache->get_read_item_guids());
 }
@@ -468,7 +468,7 @@ TEST_CASE("mark_item_deleted changes \"deleted\" flag of item with given GUID ",
 {
 	test_helpers::TempFile dbfile;
 	ConfigContainer cfg;
-	auto rsscache = std::make_unique<Cache>(dbfile.get_path(), &cfg);
+	auto rsscache = std::make_unique<Cache>(dbfile.get_path(), cfg);
 	auto feedurl = "file://data/rss.xml";
 	CurlHandle easyHandle;
 	FeedRetriever feed_retriever(cfg, *rsscache, easyHandle);
@@ -481,7 +481,7 @@ TEST_CASE("mark_item_deleted changes \"deleted\" flag of item with given GUID ",
 	rsscache->externalize_rssfeed(*feed, false);
 	rsscache->mark_item_deleted(guid, true);
 
-	rsscache = std::make_unique<Cache>(dbfile.get_path(), &cfg);
+	rsscache = std::make_unique<Cache>(dbfile.get_path(), cfg);
 	feed = rsscache->internalize_rssfeed(feedurl, nullptr);
 	// One item was deleted, so shouldn't have been loaded
 	REQUIRE(feed->total_item_count() == 7);
@@ -492,7 +492,7 @@ TEST_CASE("mark_items_read_by_guid marks items with given GUIDs as unread ",
 {
 	test_helpers::TempFile dbfile;
 	ConfigContainer cfg;
-	auto rsscache = std::make_unique<Cache>(dbfile.get_path(), &cfg);
+	auto rsscache = std::make_unique<Cache>(dbfile.get_path(), cfg);
 	auto feedurl = "file://data/rss.xml";
 	CurlHandle easyHandle;
 	FeedRetriever feed_retriever(cfg, *rsscache, easyHandle);
@@ -506,7 +506,7 @@ TEST_CASE("mark_items_read_by_guid marks items with given GUIDs as unread ",
 
 		REQUIRE_NOTHROW(rsscache->mark_items_read_by_guid({}));
 
-		rsscache = std::make_unique<Cache>(dbfile.get_path(), &cfg);
+		rsscache = std::make_unique<Cache>(dbfile.get_path(), cfg);
 		feed = rsscache->internalize_rssfeed(feedurl, nullptr);
 		REQUIRE(feed->unread_item_count() == 8);
 	}
@@ -519,7 +519,7 @@ TEST_CASE("mark_items_read_by_guid marks items with given GUIDs as unread ",
 
 		REQUIRE_NOTHROW(rsscache->mark_items_read_by_guid(guids));
 
-		rsscache = std::make_unique<Cache>(dbfile.get_path(), &cfg);
+		rsscache = std::make_unique<Cache>(dbfile.get_path(), cfg);
 		feed = rsscache->internalize_rssfeed(feedurl, nullptr);
 		REQUIRE(feed->unread_item_count() == 6);
 	}
@@ -531,11 +531,11 @@ TEST_CASE(
 	"[Cache]")
 {
 	ConfigContainer cfg;
-	Cache rsscache(":memory:", &cfg);
+	auto rsscache = Cache::in_memory(cfg);
 	auto feedurl = "file://data/rss.xml";
 	CurlHandle easyHandle;
-	FeedRetriever feed_retriever(cfg, rsscache, easyHandle);
-	RssParser parser(feedurl, rsscache, cfg, nullptr);
+	FeedRetriever feed_retriever(cfg, *rsscache, easyHandle);
+	RssParser parser(feedurl, *rsscache, cfg, nullptr);
 	auto feed = parser.parse(feed_retriever.retrieve(feedurl));
 
 	REQUIRE(feed->total_item_count() == 8);
@@ -547,10 +547,10 @@ TEST_CASE(
 		feed->items()[2]->guid(), feed->items()[5]->guid()
 	};
 
-	rsscache.externalize_rssfeed(*feed, false);
+	rsscache->externalize_rssfeed(*feed, false);
 
 	for (const auto& guid : should_be_absent) {
-		rsscache.mark_item_deleted(guid, true);
+		rsscache->mark_item_deleted(guid, true);
 	}
 
 	std::vector<std::shared_ptr<RssItem>> remaining_items;
@@ -565,17 +565,17 @@ TEST_CASE(
 		}
 	}
 	feed->set_items(remaining_items);
-	REQUIRE_NOTHROW(rsscache.remove_old_deleted_items(feed.get()));
+	REQUIRE_NOTHROW(rsscache->remove_old_deleted_items(feed.get()));
 
 	// Trying to "undelete" items
 	for (const auto& guid : should_be_absent) {
-		rsscache.mark_item_deleted(guid, false);
+		rsscache->mark_item_deleted(guid, false);
 	}
 	for (const auto& guid : should_be_present) {
-		rsscache.mark_item_deleted(guid, false);
+		rsscache->mark_item_deleted(guid, false);
 	}
 
-	feed = rsscache.internalize_rssfeed(feedurl, nullptr);
+	feed = rsscache->internalize_rssfeed(feedurl, nullptr);
 	// Two items should've been removed by remove_old_deleted_items
 	REQUIRE(feed->total_item_count() == 6);
 }
@@ -584,17 +584,17 @@ TEST_CASE("search_for_items finds all items with matching title or content",
 	"[Cache]")
 {
 	ConfigContainer cfg;
-	Cache rsscache(":memory:", &cfg);
+	auto rsscache = Cache::in_memory(cfg);
 	std::vector<std::string> feedurls = {
 		"file://data/atom10_1.xml", "file://data/rss20_1.xml"
 	};
 	for (const auto& url : feedurls) {
 		CurlHandle easyHandle;
-		FeedRetriever feed_retriever(cfg, rsscache, easyHandle);
-		RssParser parser(url, rsscache, cfg, nullptr);
+		FeedRetriever feed_retriever(cfg, *rsscache, easyHandle);
+		RssParser parser(url, *rsscache, cfg, nullptr);
 		auto feed = parser.parse(feed_retriever.retrieve(url));
 
-		rsscache.externalize_rssfeed(*feed, false);
+		rsscache->externalize_rssfeed(*feed, false);
 	}
 
 	auto query = "content";
@@ -602,17 +602,17 @@ TEST_CASE("search_for_items finds all items with matching title or content",
 
 	RssIgnores ign;
 	SECTION("Search the whole DB") {
-		REQUIRE_NOTHROW(items = rsscache.search_for_items(query, "", ign));
+		REQUIRE_NOTHROW(items = rsscache->search_for_items(query, "", ign));
 		REQUIRE(items.size() == 4);
 	}
 
 	SECTION("Search specific feed") {
 		REQUIRE_NOTHROW(
-			items = rsscache.search_for_items(query, feedurls[0], ign));
+			items = rsscache->search_for_items(query, feedurls[0], ign));
 		REQUIRE(items.size() == 3);
 
 		REQUIRE_NOTHROW(
-			items = rsscache.search_for_items(query, feedurls[1], ign));
+			items = rsscache->search_for_items(query, feedurls[1], ign));
 		REQUIRE(items.size() == 1);
 	}
 }
@@ -622,7 +622,7 @@ TEST_CASE("update_rssitem_flags dumps `rss_item` object's flags to DB",
 {
 	test_helpers::TempFile dbfile;
 	ConfigContainer cfg;
-	auto rsscache = std::make_unique<Cache>(dbfile.get_path(), &cfg);
+	auto rsscache = std::make_unique<Cache>(dbfile.get_path(), cfg);
 	const auto feedurl = "file://data/rss.xml";
 	CurlHandle easyHandle;
 	FeedRetriever feed_retriever(cfg, *rsscache, easyHandle);
@@ -634,7 +634,7 @@ TEST_CASE("update_rssitem_flags dumps `rss_item` object's flags to DB",
 	item->set_flags("abc");
 	REQUIRE_NOTHROW(rsscache->update_rssitem_flags(item.get()));
 
-	rsscache = std::make_unique<Cache>(dbfile.get_path(), &cfg);
+	rsscache = std::make_unique<Cache>(dbfile.get_path(), cfg);
 	feed = rsscache->internalize_rssfeed("file://data/rss.xml", nullptr);
 
 	REQUIRE(feed->items()[0]->flags() == "abc");
@@ -647,7 +647,7 @@ TEST_CASE(
 {
 	test_helpers::TempFile dbfile;
 	ConfigContainer cfg;
-	auto rsscache = std::make_unique<Cache>(dbfile.get_path(), &cfg);
+	auto rsscache = std::make_unique<Cache>(dbfile.get_path(), cfg);
 	const auto feedurl = "file://data/rss.xml";
 	CurlHandle easyHandle;
 	FeedRetriever feed_retriever(cfg, *rsscache, easyHandle);
@@ -664,7 +664,7 @@ TEST_CASE(
 
 		REQUIRE_NOTHROW(rsscache->update_rssitem_unread_and_enqueued(
 				*item, feedurl));
-		rsscache = std::make_unique<Cache>(dbfile.get_path(), &cfg);
+		rsscache = std::make_unique<Cache>(dbfile.get_path(), cfg);
 		feed = rsscache->internalize_rssfeed(feedurl, nullptr);
 
 		REQUIRE_FALSE(feed->items()[0]->unread());
@@ -676,7 +676,7 @@ TEST_CASE(
 
 		REQUIRE_NOTHROW(rsscache->update_rssitem_unread_and_enqueued(
 				*item, feedurl));
-		rsscache = std::make_unique<Cache>(dbfile.get_path(), &cfg);
+		rsscache = std::make_unique<Cache>(dbfile.get_path(), cfg);
 		feed = rsscache->internalize_rssfeed(feedurl, nullptr);
 
 		REQUIRE(feed->items()[0]->enqueued());
@@ -690,7 +690,7 @@ TEST_CASE(
 
 		REQUIRE_NOTHROW(rsscache->update_rssitem_unread_and_enqueued(
 				*item, feedurl));
-		rsscache = std::make_unique<Cache>(dbfile.get_path(), &cfg);
+		rsscache = std::make_unique<Cache>(dbfile.get_path(), cfg);
 		feed = rsscache->internalize_rssfeed(feedurl, nullptr);
 
 		REQUIRE_FALSE(feed->items()[0]->unread());
@@ -748,7 +748,7 @@ TEST_CASE(
 
 	test_helpers::TempFile dbfile;
 	ConfigContainer cfg;
-	auto rsscache = std::make_unique<Cache>(dbfile.get_path(), &cfg);
+	auto rsscache = std::make_unique<Cache>(dbfile.get_path(), cfg);
 	const auto feedurl = "file://data/rss.xml";
 	CurlHandle easyHandle;
 	FeedRetriever feed_retriever(cfg, *rsscache, easyHandle);
@@ -761,7 +761,7 @@ TEST_CASE(
 	SECTION("Simple case") {
 		rsscache->externalize_rssfeed(*initial_feed, false);
 
-		rsscache = std::make_unique<Cache>(dbfile.get_path(), &cfg);
+		rsscache = std::make_unique<Cache>(dbfile.get_path(), cfg);
 		auto new_feed = rsscache->internalize_rssfeed(feedurl, nullptr);
 		new_feed->load();
 
@@ -773,7 +773,7 @@ TEST_CASE(
 		rsscache->externalize_rssfeed(*initial_feed, false);
 		rsscache->externalize_rssfeed(*initial_feed, false);
 
-		rsscache = std::make_unique<Cache>(dbfile.get_path(), &cfg);
+		rsscache = std::make_unique<Cache>(dbfile.get_path(), cfg);
 		auto new_feed = rsscache->internalize_rssfeed(feedurl, nullptr);
 		new_feed->load();
 
@@ -786,7 +786,7 @@ TEST_CASE("externalize_rssfeed doesn't store more than `max-items` items",
 {
 	test_helpers::TempFile dbfile;
 	auto cfg = std::make_unique<ConfigContainer>();
-	auto rsscache = std::make_unique<Cache>(dbfile.get_path(), cfg.get());
+	auto rsscache = std::make_unique<Cache>(dbfile.get_path(), *cfg);
 
 	cfg->set_configvalue("max-items", "3");
 	const auto feedurl = "file://data/rss.xml";
@@ -798,7 +798,7 @@ TEST_CASE("externalize_rssfeed doesn't store more than `max-items` items",
 	rsscache->externalize_rssfeed(*feed, false);
 
 	cfg = std::make_unique<ConfigContainer>();
-	rsscache = std::make_unique<Cache>(dbfile.get_path(), cfg.get());
+	rsscache = std::make_unique<Cache>(dbfile.get_path(), *cfg);
 	feed = rsscache->internalize_rssfeed(feedurl, nullptr);
 	REQUIRE(feed->total_item_count() == 3);
 }
@@ -815,7 +815,7 @@ TEST_CASE(
 {
 	test_helpers::TempFile dbfile;
 	auto cfg = std::make_unique<ConfigContainer>();
-	auto rsscache = std::make_unique<Cache>(dbfile.get_path(), cfg.get());
+	auto rsscache = std::make_unique<Cache>(dbfile.get_path(), *cfg);
 
 	const auto feedurl = "file://data/rss.xml";
 	CurlHandle easyHandle;
@@ -829,7 +829,7 @@ TEST_CASE(
 
 		cfg = std::make_unique<ConfigContainer>();
 		cfg->set_configvalue("max-items", "3");
-		rsscache = std::make_unique<Cache>(dbfile.get_path(), cfg.get());
+		rsscache = std::make_unique<Cache>(dbfile.get_path(), *cfg);
 		feed = rsscache->internalize_rssfeed(feedurl, nullptr);
 		REQUIRE(feed->total_item_count() == 3);
 	}
@@ -843,7 +843,7 @@ TEST_CASE(
 
 		cfg = std::make_unique<ConfigContainer>();
 		cfg->set_configvalue("max-items", "1");
-		rsscache = std::make_unique<Cache>(dbfile.get_path(), cfg.get());
+		rsscache = std::make_unique<Cache>(dbfile.get_path(), *cfg);
 		feed = rsscache->internalize_rssfeed(feedurl, nullptr);
 		// All flagged items should be present no matter what
 		unsigned int flagged_count = 0;
@@ -861,9 +861,9 @@ TEST_CASE(
 	"[Cache]")
 {
 	ConfigContainer cfg;
-	Cache rsscache(":memory:", &cfg);
+	auto rsscache = Cache::in_memory(cfg);
 	auto feedurl = "query:misc:age between 0:10";
-	auto feed = rsscache.internalize_rssfeed(feedurl, nullptr);
+	auto feed = rsscache->internalize_rssfeed(feedurl, nullptr);
 
 	REQUIRE(feed->total_item_count() == 0);
 	REQUIRE(feed->rssurl() == feedurl);
@@ -873,22 +873,22 @@ TEST_CASE("internalize_rssfeed doesn't return items that are ignored",
 	"[Cache]")
 {
 	ConfigContainer cfg;
-	Cache rsscache(":memory:", &cfg);
+	auto rsscache = Cache::in_memory(cfg);
 
 	const std::string feedurl("file://data/rss092_1.xml");
 	CurlHandle easyHandle;
-	FeedRetriever feed_retriever(cfg, rsscache, easyHandle);
-	RssParser parser(feedurl, rsscache, cfg, nullptr);
+	FeedRetriever feed_retriever(cfg, *rsscache, easyHandle);
+	RssParser parser(feedurl, *rsscache, cfg, nullptr);
 	auto feed = parser.parse(feed_retriever.retrieve(feedurl));
 	REQUIRE(feed->total_item_count() == 3);
-	rsscache.externalize_rssfeed(*feed, false);
+	rsscache->externalize_rssfeed(*feed, false);
 
 	RssIgnores ign;
 	ign.handle_action("ignore-article", {"*", "title =~ \"third\""});
 
-	feed = rsscache.internalize_rssfeed(feedurl, nullptr);
+	feed = rsscache->internalize_rssfeed(feedurl, nullptr);
 	REQUIRE(feed->total_item_count() == 3);
-	feed = rsscache.internalize_rssfeed(feedurl, &ign);
+	feed = rsscache->internalize_rssfeed(feedurl, &ign);
 	REQUIRE(feed->total_item_count() == 2);
 }
 
@@ -899,7 +899,7 @@ TEST_CASE(
 {
 	test_helpers::TempFile dbfile;
 	ConfigContainer cfg;
-	auto rsscache = std::make_unique<Cache>(dbfile.get_path(), &cfg);
+	auto rsscache = std::make_unique<Cache>(dbfile.get_path(), cfg);
 	auto feedurl = "file://data/rss.xml";
 	CurlHandle easyHandle;
 	FeedRetriever feed_retriever(cfg, *rsscache, easyHandle);
@@ -908,7 +908,7 @@ TEST_CASE(
 	feed->items()[0]->set_unread_nowrite(false);
 	rsscache->externalize_rssfeed(*feed, false);
 
-	rsscache = std::make_unique<Cache>(dbfile.get_path(), &cfg);
+	rsscache = std::make_unique<Cache>(dbfile.get_path(), cfg);
 	feed = rsscache->internalize_rssfeed(feedurl, nullptr);
 	feed->load();
 	REQUIRE_FALSE(feed->items()[0]->unread());
@@ -917,14 +917,14 @@ TEST_CASE(
 
 	SECTION("reset_unread = false; item remains read") {
 		rsscache->externalize_rssfeed(*feed, false);
-		rsscache = std::make_unique<Cache>(dbfile.get_path(), &cfg);
+		rsscache = std::make_unique<Cache>(dbfile.get_path(), cfg);
 		feed = rsscache->internalize_rssfeed(feedurl, nullptr);
 		REQUIRE_FALSE(feed->items()[0]->unread());
 	}
 
 	SECTION("reset_unread = true; item becomes unread") {
 		rsscache->externalize_rssfeed(*feed, true);
-		rsscache = std::make_unique<Cache>(dbfile.get_path(), &cfg);
+		rsscache = std::make_unique<Cache>(dbfile.get_path(), cfg);
 		feed = rsscache->internalize_rssfeed(feedurl, nullptr);
 		REQUIRE(feed->items()[0]->unread());
 	}
@@ -937,7 +937,7 @@ TEST_CASE(
 {
 	test_helpers::TempFile dbfile;
 	ConfigContainer cfg;
-	auto rsscache = std::make_unique<Cache>(dbfile.get_path(), &cfg);
+	auto rsscache = std::make_unique<Cache>(dbfile.get_path(), cfg);
 	auto feedurl = "file://data/rss.xml";
 	CurlHandle easyHandle;
 	FeedRetriever feed_retriever(cfg, *rsscache, easyHandle);
@@ -946,14 +946,14 @@ TEST_CASE(
 	feed->items()[0]->set_unread_nowrite(false);
 	rsscache->externalize_rssfeed(*feed, false);
 
-	rsscache = std::make_unique<Cache>(dbfile.get_path(), &cfg);
+	rsscache = std::make_unique<Cache>(dbfile.get_path(), cfg);
 	feed = rsscache->internalize_rssfeed(feedurl, nullptr);
 	auto item = feed->items()[0];
 	item->set_unread_nowrite(true);
 
 	SECTION("override_unread not set; item remains read") {
 		rsscache->externalize_rssfeed(*feed, false);
-		rsscache = std::make_unique<Cache>(dbfile.get_path(), &cfg);
+		rsscache = std::make_unique<Cache>(dbfile.get_path(), cfg);
 		feed = rsscache->internalize_rssfeed(feedurl, nullptr);
 		REQUIRE_FALSE(feed->items()[0]->unread());
 	}
@@ -961,7 +961,7 @@ TEST_CASE(
 	SECTION("override_unread is set; item becomes unread") {
 		item->set_override_unread(true);
 		rsscache->externalize_rssfeed(*feed, false);
-		rsscache = std::make_unique<Cache>(dbfile.get_path(), &cfg);
+		rsscache = std::make_unique<Cache>(dbfile.get_path(), cfg);
 		feed = rsscache->internalize_rssfeed(feedurl, nullptr);
 		REQUIRE(feed->items()[0]->unread());
 	}
@@ -974,7 +974,7 @@ TEST_CASE(
 {
 	test_helpers::TempFile dbfile;
 	ConfigContainer cfg;
-	auto rsscache = std::make_unique<Cache>(dbfile.get_path(), &cfg);
+	auto rsscache = std::make_unique<Cache>(dbfile.get_path(), cfg);
 
 	auto feed = std::make_shared<RssFeed>(rsscache.get(),
 			"query:All unread:unread = \"yes\"");
@@ -999,7 +999,7 @@ TEST_CASE(
 	// can't be done by direct assignment because sqlite3_open doesn't
 	// return that pointer)
 	sqlite3* dbptr = nullptr;
-	int error = sqlite3_open(dbfile.get_path().c_str(), &dbptr);
+	int error = sqlite3_open(dbfile.get_path().to_locale_string().c_str(), &dbptr);
 	REQUIRE(error == SQLITE_OK);
 	db.reset(dbptr);
 	dbptr = nullptr;
@@ -1030,7 +1030,7 @@ TEST_CASE("do_vacuum doesn't throw an exception", "[Cache]")
 {
 	test_helpers::TempFile dbfile;
 	ConfigContainer cfg;
-	auto rsscache = std::make_unique<Cache>(dbfile.get_path(), &cfg);
+	auto rsscache = std::make_unique<Cache>(dbfile.get_path(), cfg);
 	const std::string uri = "file://data/rss.xml";
 	CurlHandle easyHandle;
 	FeedRetriever feed_retriever(cfg, *rsscache, easyHandle);
@@ -1041,21 +1041,21 @@ TEST_CASE("do_vacuum doesn't throw an exception", "[Cache]")
 	REQUIRE_NOTHROW(rsscache->do_vacuum());
 
 	// Checking that Cache can still be opened
-	REQUIRE_NOTHROW(rsscache.reset(new Cache(dbfile.get_path(), &cfg)));
+	REQUIRE_NOTHROW(rsscache.reset(new Cache(dbfile.get_path(), cfg)));
 }
 
 TEST_CASE("search_in_items returns items that contain given substring",
 	"[Cache]")
 {
 	ConfigContainer cfg;
-	Cache rsscache(":memory:", &cfg);
+	auto rsscache = Cache::in_memory(cfg);
 	const std::string uri = "file://data/rss.xml";
 	CurlHandle easyHandle;
-	FeedRetriever feed_retriever(cfg, rsscache, easyHandle);
-	RssParser parser(uri, rsscache, cfg, nullptr);
+	FeedRetriever feed_retriever(cfg, *rsscache, easyHandle);
+	RssParser parser(uri, *rsscache, cfg, nullptr);
 	auto feed = parser.parse(feed_retriever.retrieve(uri));
 	REQUIRE(feed->total_item_count() == 8);
-	rsscache.externalize_rssfeed(*feed, false);
+	rsscache->externalize_rssfeed(*feed, false);
 
 	using guids = std::unordered_set<std::string>;
 
@@ -1078,7 +1078,7 @@ TEST_CASE("search_in_items returns items that contain given substring",
 	}
 
 	const guids with_botox =
-		rsscache.search_in_items("Botox", guids_from_feed);
+		rsscache->search_in_items("Botox", guids_from_feed);
 	for (const auto& guid : with_botox) {
 		INFO("Checking GUID " << guid);
 		REQUIRE_FALSE(
@@ -1091,37 +1091,37 @@ TEST_CASE("search_in_items returns items that contain given substring",
 TEST_CASE("search_in_items returns empty set if input set is empty", "[Cache]")
 {
 	ConfigContainer cfg;
-	Cache rsscache(":memory:", &cfg);
+	auto rsscache = Cache::in_memory(cfg);
 	const std::string uri = "file://data/rss.xml";
 	CurlHandle easyHandle;
-	FeedRetriever feed_retriever(cfg, rsscache, easyHandle);
-	RssParser parser(uri, rsscache, cfg, nullptr);
+	FeedRetriever feed_retriever(cfg, *rsscache, easyHandle);
+	RssParser parser(uri, *rsscache, cfg, nullptr);
 	auto feed = parser.parse(feed_retriever.retrieve(uri));
-	rsscache.externalize_rssfeed(*feed, false);
+	rsscache->externalize_rssfeed(*feed, false);
 
 	using guids = std::unordered_set<std::string>;
 	std::unordered_set<std::string> empty;
-	const guids result = rsscache.search_in_items("Botox", empty);
+	const guids result = rsscache->search_in_items("Botox", empty);
 	REQUIRE(result.empty());
 }
 
 TEST_CASE("Ignoring articles in search", "[Cache]")
 {
 	ConfigContainer cfg{};
-	Cache rsscache(":memory:", &cfg);
+	auto rsscache = Cache::in_memory(cfg);
 
 	const std::string uri = "file://data/rss.xml";
 	CurlHandle easyHandle;
-	FeedRetriever feed_retriever(cfg, rsscache, easyHandle);
-	RssParser parser(uri, rsscache, cfg, nullptr);
+	FeedRetriever feed_retriever(cfg, *rsscache, easyHandle);
+	RssParser parser(uri, *rsscache, cfg, nullptr);
 	auto feed = parser.parse(feed_retriever.retrieve(uri));
 	REQUIRE(feed->total_item_count() == 8);
-	rsscache.externalize_rssfeed(*feed, false);
+	rsscache->externalize_rssfeed(*feed, false);
 
 	RssIgnores ign, empty_ign;
 	ign.handle_action("ignore-article", {"*", "title =~ \"Botox\""});
-	auto search_items = rsscache.search_for_items("Botox", "", ign);
-	auto no_ignore_items = rsscache.search_for_items("Botox", "", empty_ign);
+	auto search_items = rsscache->search_for_items("Botox", "", ign);
+	auto no_ignore_items = rsscache->search_for_items("Botox", "", empty_ign);
 
 	REQUIRE(search_items.size() == 0 );
 	REQUIRE(no_ignore_items.size() == 1);
