@@ -29,8 +29,8 @@ TEST_CASE("opml::generate creates an XML document with feed URLs in OPML format"
 		xmlFreeDoc(opml);
 
 		const std::string opmlText(
-			reinterpret_cast<char*>(buffer->content),
-			buffer->use);
+			reinterpret_cast<const char*>(xmlBufferContent(buffer)),
+			xmlBufferLength(buffer));
 
 		xmlBufferFree(buffer);
 		buffer = nullptr;
@@ -52,16 +52,16 @@ TEST_CASE("opml::generate creates an XML document with feed URLs in OPML format"
 
 	SECTION("A few feeds") {
 		ConfigContainer cfg;
-		Cache rsscache(":memory:", &cfg);
+		auto rsscache = Cache::in_memory(cfg);
 		FeedContainer feeds;
 
 		std::shared_ptr<RssFeed> feed =
-			std::make_shared<RssFeed>(&rsscache, "https://example.com/feed1.xml");
+			std::make_shared<RssFeed>(rsscache.get(), "https://example.com/feed1.xml");
 		feed->set_title("Feed 1");
 		feed->set_link("https://example.com/feed1/");
 		feeds.add_feed(std::move(feed));
 
-		feed = std::make_shared<RssFeed>(&rsscache, "https://example.com/feed2.xml");
+		feed = std::make_shared<RssFeed>(rsscache.get(), "https://example.com/feed2.xml");
 		feed->set_title("Feed 2");
 		feed->set_link("https://example.com/feed2/");
 		feed->set_tags({"tag", "tag,with,commas", "tag/with/slashes", "tag with spaces"});
@@ -114,7 +114,8 @@ TEST_CASE("import() populates UrlReader with URLs from the OPML file", "[Opml]")
 {
 	test_helpers::TempFile urlsFile;
 
-	test_helpers::copy_file("data/test-urls.txt", urlsFile.get_path());
+	test_helpers::copy_file("data/test-urls.txt"_path,
+		urlsFile.get_path());
 
 	using URL = std::string;
 	using Tag = std::string;
@@ -140,19 +141,20 @@ TEST_CASE("import() populates UrlReader with URLs from the OPML file", "[Opml]")
 		REQUIRE(tags == entry->second);
 	}
 
-	REQUIRE_NOTHROW(
-		opml::import(
-			"file://" + utils::getcwd() + "/data/example.opml",
-			urlcfg));
+	const auto path =
+		"file:/"_path // `Filepath` will append an extra slash
+		.join(utils::getcwd())
+		.join("data/example.opml"_path);
+	REQUIRE_NOTHROW(opml::import(path, urlcfg));
 
 	const std::map<URL, Tags> opmlUrls {
-		{"https://example.com/feed.xml", {}},
-		{"https://example.com/mirrors/distrowatch.rss", {}},
-		{"https://example.com/feed.atom", {}},
-		{"https://example.com/feed.rss09", {}},
-		{"https://blogs.example.com/~john/posts.rss", {"Blogs"}},
-		{"https://blogs.example.com/~mike/.rss", {"Blogs/friends"}},
-		{"https://fred.example.com/writing/index.php?type=rss", {"eloquent"}},
+		{"https://example.com/feed.xml", {"~example.com website"}},
+		{"https://example.com/mirrors/distrowatch.rss", {"~Distrowatch mirror"}},
+		{"https://example.com/feed.atom", {"~example.com website (Atom feed)"}},
+		{"https://example.com/feed.rss09", {"~example.com website (RSS 0.9 feed)"}},
+		{"https://blogs.example.com/~john/posts.rss", {"~John's musings", "Blogs"}},
+		{"https://blogs.example.com/~mike/.rss", {"~Notes by Mike", "Blogs/friends"}},
+		{"https://fred.example.com/writing/index.php?type=rss", {"~Fred on everything", "eloquent"}},
 	};
 
 	std::map<URL, Tags> combinedUrls;
@@ -180,17 +182,18 @@ TEST_CASE("import() turns URLs that start with a pipe symbol (\"|\") "
 	FileUrlReader urlcfg(urlsFile.get_path());
 	urlcfg.reload();
 
-	REQUIRE_NOTHROW(
-		opml::import(
-			"file://" + utils::getcwd() + "/data/piped.opml",
-			urlcfg));
+	const auto path =
+		"file:/"_path // `Filepath` will append an extra slash
+		.join(utils::getcwd())
+		.join("data/piped.opml"_path);
+	REQUIRE_NOTHROW(opml::import(path, urlcfg));
 
 	using URL = std::string;
 	using Tag = std::string;
 	using Tags = std::vector<Tag>;
 	const std::map<URL, Tags> opmlUrls {
-		{"exec:~/fetch_tweets.py", {}},
-		{"https://example.com/feed.atom", {"tagged"}},
+		{"exec:~/fetch_tweets.py", {"~Birdsite search"}},
+		{"https://example.com/feed.atom", {"~example.com website (Atom feed)", "tagged"}},
 	};
 
 	REQUIRE(urlcfg.get_urls().size() == opmlUrls.size());
@@ -215,17 +218,18 @@ TEST_CASE("import() turns \"filtercmd\" attribute into a `filter:` URL "
 	FileUrlReader urlcfg(urlsFile.get_path());
 	urlcfg.reload();
 
-	REQUIRE_NOTHROW(
-		opml::import(
-			"file://" + utils::getcwd() + "/data/filtered.opml",
-			urlcfg));
+	const auto path =
+		"file:/"_path // `Filepath` will append an extra slash
+		.join(utils::getcwd())
+		.join("data/filtered.opml"_path);
+	REQUIRE_NOTHROW(opml::import(path, urlcfg));
 
 	using URL = std::string;
 	using Tag = std::string;
 	using Tags = std::vector<Tag>;
 	const std::map<URL, Tags> opmlUrls {
-		{"https://example.com/another_feed.atom", {"misc"}},
-		{"filter:~/.bin/keep_interesting.pl:https://example.com/firehose", {}},
+		{"https://example.com/another_feed.atom", {"~example.com website (Atom feed)", "misc"}},
+		{"filter:~/.bin/keep_interesting.pl:https://example.com/firehose", {"~Firehose"}},
 	};
 
 	REQUIRE(urlcfg.get_urls().size() == opmlUrls.size());
@@ -246,7 +250,8 @@ TEST_CASE("import() skips URLs that are already present in UrlReader",
 {
 	test_helpers::TempFile urlsFile;
 
-	test_helpers::copy_file("data/test-urls.txt", urlsFile.get_path());
+	test_helpers::copy_file("data/test-urls.txt"_path,
+		urlsFile.get_path());
 
 	using URL = std::string;
 	using Tag = std::string;
@@ -272,13 +277,14 @@ TEST_CASE("import() skips URLs that are already present in UrlReader",
 		REQUIRE(tags == entry->second);
 	}
 
-	REQUIRE_NOTHROW(
-		opml::import(
-			"file://" + utils::getcwd() + "/data/test-urls+.opml",
-			urlcfg));
+	const auto path =
+		"file:/"_path // `Filepath` will append an extra slash
+		.join(utils::getcwd())
+		.join("data/test-urls+.opml"_path);
+	REQUIRE_NOTHROW(opml::import(path, urlcfg));
 
 	const std::map<URL, Tags> opmlUrls {
-		{"https://example.com/another_feed.atom", {}},
+		{"https://example.com/another_feed.atom", {"~example.com website (Atom feed)"}},
 	};
 
 	std::map<URL, Tags> combinedUrls;
@@ -301,9 +307,11 @@ TEST_CASE("import() skips URLs that are already present in UrlReader",
 TEST_CASE("import() tags from category attribute", "[Opml]")
 {
 	FileUrlReader urlcfg;
-	REQUIRE_NOTHROW(
-		opml::import("file://" + utils::getcwd() + "/data/category.opml", urlcfg)
-	);
+	const auto path =
+		"file:/"_path // `Filepath` will append an extra slash
+		.join(utils::getcwd())
+		.join("data/category.opml"_path);
+	REQUIRE_NOTHROW(opml::import(path, urlcfg));
 
 	const std::vector<std::string> tags{"tag one", "tag_two", "tag/three"};
 	const auto& urls = urlcfg.get_urls();
