@@ -5,15 +5,15 @@
 
 #include "utils.h"
 
-test_helpers::Chdir::Chdir(const std::string& path)
+test_helpers::Chdir::Chdir(const newsboat::Filepath& path)
 {
 	m_old_path = newsboat::utils::getcwd();
-	const int result = ::chdir(path.c_str());
+	const int result = ::chdir(path.to_locale_string().c_str());
 	if (result != 0) {
 		const auto saved_errno = errno;
 		auto msg = std::string("test_helpers::Chdir: ")
 			+ "couldn't change current directory to `"
-			+ path
+			+ path.display()
 			+ "': ("
 			+ std::to_string(saved_errno)
 			+ ") "
@@ -26,6 +26,6 @@ test_helpers::Chdir::~Chdir()
 {
 	// Ignore the return value, because even if the call failed, we
 	// can't do anything useful.
-	const int result = ::chdir(m_old_path.c_str());
+	const int result = ::chdir(m_old_path.to_locale_string().c_str());
 	(void)result;
 }
