@@ -1,17 +1,17 @@
 #ifndef NEWSBOAT_TEST_HELPERS_CHDIR_H_
 #define NEWSBOAT_TEST_HELPERS_CHDIR_H_
 
-#include <string>
+#include "filepath.h"
 
 namespace test_helpers {
 
 /// Changes current working directory and restores it back when the object is
 /// destroyed.
 class Chdir {
-	std::string m_old_path;
+	newsboat::Filepath m_old_path;
 
 public:
-	Chdir(const std::string& path);
+	Chdir(const newsboat::Filepath& path);
 
 	~Chdir();
 };
