@@ -1,7 +1,7 @@
 #ifndef NEWSBOAT_TEST_HELPERS_CHMOD_H_
 #define NEWSBOAT_TEST_HELPERS_CHMOD_H_
 
-#include <string>
+#include "filepath.h"
 #include <sys/stat.h>
 
 namespace test_helpers {
@@ -9,11 +9,11 @@ namespace test_helpers {
 /// Sets new permissions on a given path, and restores them back when the
 /// object is destroyed.
 class Chmod {
-	std::string m_path;
+	newsboat::Filepath m_path;
 	mode_t m_originalMode;
 
 public:
-	Chmod(const std::string& path, mode_t newMode);
+	Chmod(const newsboat::Filepath& path, mode_t newMode);
 
 	~Chmod();
 };
