@@ -6,9 +6,12 @@
 #include <sys/types.h>
 #include <unistd.h>
 
+using newsboat::operator""_path;
+
 test_helpers::MainTempDir::tempfileexception::tempfileexception(
+	const newsboat::Filepath& filepath,
 	const std::string& error)
-	: msg("tempfileexception: " + error)
+	: msg("tempfileexception: " + filepath.display() + ": " + error)
 {
 };
 
@@ -22,14 +25,15 @@ test_helpers::MainTempDir::MainTempDir()
 	char* tmpdir_p = ::getenv("TMPDIR");
 
 	if (tmpdir_p) {
-		tempdir = tmpdir_p;
+		tempdir = newsboat::Filepath::from_locale_string(tmpdir_p);
 	} else {
-		tempdir = "/tmp/";
+		tempdir = "/tmp"_path;
 	}
 
-	tempdir += "/newsboat-tests/";
+	tempdir.push("newsboat-tests"_path);
 
-	int status = mkdir(tempdir.c_str(), S_IRWXU);
+	const auto tempdir_str = tempdir.to_locale_string();
+	int status = mkdir(tempdir_str.c_str(), S_IRWXU);
 	if (status != 0) {
 		// The directory already exists. That's fine, though,
 		// but only as long as it has all the properties we
@@ -40,7 +44,7 @@ test_helpers::MainTempDir::MainTempDir()
 
 		if (saved_errno == EEXIST) {
 			struct stat buffer;
-			if (lstat(tempdir.c_str(), &buffer) == 0) {
+			if (lstat(tempdir_str.c_str(), &buffer) == 0) {
 				if (buffer.st_mode & S_IRUSR &&
 					buffer.st_mode & S_IWUSR &&
 					buffer.st_mode & S_IXUSR) {
@@ -50,7 +54,7 @@ test_helpers::MainTempDir::MainTempDir()
 		}
 
 		if (!success) {
-			throw tempfileexception(strerror(saved_errno));
+			throw tempfileexception(tempdir, strerror(saved_errno));
 		}
 	}
 }
@@ -59,10 +63,11 @@ test_helpers::MainTempDir::~MainTempDir()
 {
 	// Try to remove the tempdir, but don't try *too* hard: there might be
 	// other objects still using it. The last one will hopefully delete it.
-	::rmdir(tempdir.c_str());
+	const auto tempdir_str = tempdir.to_locale_string();
+	::rmdir(tempdir_str.c_str());
 }
 
-const std::string test_helpers::MainTempDir::get_path() const
+newsboat::Filepath test_helpers::MainTempDir::get_path() const
 {
 	return tempdir;
 }
