@@ -6,6 +6,7 @@
 #include "controller.h"
 #include "configpaths.h"
 #include "cache.h"
+#include "filepath.h"
 
 using namespace newsboat;
 
@@ -19,25 +20,20 @@ TEST_CASE("get_filename_suggestion() normalizes filenames for saving articles",
 
 	ConfigPaths paths{};
 	Controller c(paths);
-	newsboat::View v(&c);
+	newsboat::View v(c);
 
 	ConfigContainer cfg{};
-	Cache rsscache(":memory:", &cfg);
 
 	v.set_config_container(&cfg);
 	c.set_view(&v);
 
 	// Default case is exclusively ASCII characters. Should never fail.
-	REQUIRE(v.get_filename_suggestion(example_en).compare("Comparing_Visual.txt") ==
-		0);
-
-	REQUIRE(v.get_filename_suggestion(
-			example_ru).compare("Инженеры_из_MIT.txt") != 0);
-	REQUIRE(v.get_filename_suggestion(example_fr).compare("Les_mathématiques.txt") != 0);
+	REQUIRE(v.get_filename_suggestion(example_en) == "Comparing_Visual.txt"_path);
+	REQUIRE(v.get_filename_suggestion(example_ru) != "Инженеры_из_MIT.txt"_path);
+	REQUIRE(v.get_filename_suggestion(example_fr) != "Les_mathématiques.txt"_path);
 
 	cfg.toggle("restrict-filename");
 
-	REQUIRE(v.get_filename_suggestion(
-			example_ru).compare("Инженеры из MIT.txt") == 0);
-	REQUIRE(v.get_filename_suggestion(example_fr).compare("Les mathématiques.txt") == 0);
-}
\ No newline at end of file
+	REQUIRE(v.get_filename_suggestion(example_ru) == "Инженеры из MIT.txt"_path);
+	REQUIRE(v.get_filename_suggestion(example_fr) == "Les mathématiques.txt"_path);
+}
